// CHighSpeedVideoData.cpp

#include "highspeedvideodata.h"

CHighSpeedVideoData::CHighSpeedVideoData(void)
{
	ClearHsvddata();
}

CHighSpeedVideoData::~CHighSpeedVideoData(void)
{
}

void CHighSpeedVideoData::ClearHsvddata()
{
	m_camno.RemoveAll();
	m_vscfactor.RemoveAll();
	m_desc.RemoveAll();
	m_comment.RemoveAll();

	m_camno.SetAtGrow( 0, "");		// m_camno.SetAtGrow( 1, "");
//	m_tstref has been defined in test info
	m_camerano.SetAtGrow( 0, "");
	m_vscfactor.SetAtGrow( 0, "");	// m_vscfactor.SetAtGrow( 1, "");
	m_desc.SetAtGrow( 0, "");		// m_desc.SetAtGrow( 1, "");
	m_comment.SetAtGrow( 0, "");	// m_comment.SetAtGrow( 1, "");
}	// ClearHsvddata

bool CHighSpeedVideoData::ImportHsvd(CString& strfile_in, bool bErrMsgResponse /*=true*/)
{
	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_in, CFile::modeRead | CFile::typeText,
		&fileException );

	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		if (bErrMsgResponse)
		{
			CString msg;
			msg.Format ("Can't open file %s, error = %u\n", strfile_in, fileException.m_cause );
			MessageBox(NULL,msg,"Error",MB_OK);
		}
		return FALSE;
	}

	ReadHsvdData(myFile);
	
	myFile.Close ();
	return true;
}	// ImportHSvd

void CHighSpeedVideoData::WriteHsvdReport (CStdioFile& myFile)
{
	if( m_camno.GetSize() == 1 ) { return; }

	myFile.WriteString ("----- HSVD -----\n");

	for( int loop = 1; loop < m_camno.GetSize(); loop++ )  
	{
		myFile.WriteString ("----- CAMERA " + m_camno[loop] + " -----\n");
		myFile.WriteString ("Test Reference:	" + m_tstref + "\n");
		myFile.WriteString ("Cameras Number:	" + m_camerano[loop] + "\n");
		myFile.WriteString ("Video Frame Numbner Scale factor:	" + m_vscfactor[loop] + "\n");
		myFile.WriteString ("View Description:	" + RemoveReturn(m_desc[loop]) + "\n");
		myFile.WriteString ("Camera Commentary:	" + RemoveReturn(m_comment[loop]) + "\n");
	}
	myFile.WriteString ("----- END -----\n");
}	// WriteHsvdReport

bool CHighSpeedVideoData::ExportHsvd(CString& strfile_out)
{
	if( m_camno.GetSize() == 1 ) { return false; }

	CStdioFile myFile;
	CFileException fileException;

	myFile.Open(	strfile_out,
					CFile::modeCreate | CFile::modeReadWrite | CFile::typeText,
					&fileException );

	if( !myFile.m_pStream )  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return false;
	}
	
	CTime now = CTime::GetCurrentTime ();
	myFile.WriteString ("# Source: High Speed Video Data\n");
	CString strToday;
	strToday.Format("# Date: <%d/%d/%d>\n", now.GetMonth(), now.GetDay(), now.GetYear() );
	myFile.WriteString (strToday);
	
	WriteHsvd(myFile);

	myFile.Close ();

	return true;
}	// ExportHsvd

bool CHighSpeedVideoData::ExportHsvdReport(CString& strfile_out)
{
	if( m_camno.GetSize() == 1 ) { return false; }

	CStdioFile myFile;
	CFileException fileException;

	myFile.Open(	strfile_out,
					CFile::modeCreate | CFile::modeReadWrite | CFile::typeText,
					&fileException );

	if( !myFile.m_pStream )  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return false;
	}
	
	CTime now = CTime::GetCurrentTime ();
	myFile.WriteString ("# Source: High Speed Video Data\n");
	CString strToday;
	strToday.Format("# Date: <%d/%d/%d>\n", now.GetMonth(), now.GetDay(), now.GetYear() );
	myFile.WriteString (strToday);
	
	WriteHsvdReport(myFile);

	myFile.Close ();

	return true;
}	// ExportHsvdReport

bool CHighSpeedVideoData::ValidateEmptyHsvd()
{
	if (m_camno.GetSize()==1) { return false; }
	return true;
}	// ValidateEmptyHsvd

// private functions:
const CString CHighSpeedVideoData::OutString(CString& st)
{
	CString str = st;
	if (str=="") { str=" |"; }
	else { str+= "|"; }
	
	return str;
}

const CString CHighSpeedVideoData::RemoveReturn(const CString  st)
{
	CString str = st;
	str.Remove('\n'); 
	str.Remove('\r');
	
	return str;
}

void CHighSpeedVideoData::WriteHsvd(CStdioFile& myFile)
{

	myFile.WriteString ("----- HSVD -----\n");

	CString sLine = "";
	int n = m_camno.GetSize();
	for( int i = 1; i < n; i++ )  
	{
		sLine = OutString(m_camno[i]);
		sLine+= OutString(m_tstref);
		sLine+= OutString(m_camerano[i]);
		sLine+= OutString(m_vscfactor[i]);
		sLine+= RemoveReturn(OutString(m_desc[i]));
		sLine+= RemoveReturn(m_comment[i]);

		myFile.WriteString (sLine + "\n");
	}
	myFile.WriteString ("----- END -----\n");
}	// WriteHsvd

void CHighSpeedVideoData::ReadHsvdData(CStdioFile& myFile)
{
	CString strLine;
	myFile.SeekToBegin ();  // back to beginning

	// find ----- HSVD -----
	int nRes = -1;
	while (myFile.ReadString (strLine))
	{
		nRes = strLine.Find("----- HSVD -----");
		if (nRes != -1) break;
	}

	if (nRes==-1)  { return; } //  not found.

    // now read line after ----- HSVD -----
	myFile.ReadString (strLine);	

//	if ((strLine.GetLength ()) <1) 
//	{
//		return;  // don't process empty string
//	}

	while ((strLine[0]=='#')||(strLine.GetLength()<1))  //comment line, so read another.
	{
		myFile.ReadString (strLine);	
	}

	int loc1 = strLine.Find ('|',0);
	if (loc1==-1) 
	{
		return;      // | not found in line after ----- HSVD -----,
				     // must be another section, so return.
	}

	int loop = 1;
	while ((strLine.Find("----- END -----"))== -1)  // not at end line.
	{
		int nPipes = CountPipes(strLine);

		if (nPipes!= 5)
		{
			char buf [10];
			itoa (nPipes,buf,10);
			CString strPipes = buf;
			CString strErr = "This file has "+strPipes +" | characters in one line of the HSVD section, should have 5.";
			MessageBox(NULL, strErr, "Error",MB_OK);
			return;  // makes sure all entries are correct.
		}
		// GetTextBetweenPipes is fragile. if an index i is used it cannot work correctly in release version
		char szCh[4]; itoa(loop,szCh,10);
		m_camno.SetAtGrow(loop, szCh);
		CString temp = GetTextBetweenPipes(strLine,1,2);
		m_tstref = temp;
		temp = GetTextBetweenPipes(strLine,2,3);
		m_camerano.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 3,4);
		m_vscfactor.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 4,5);
		m_desc.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 5,6);
		m_comment.SetAtGrow(loop, temp);
	
		loop++;

		myFile.ReadString (strLine);

		while (strLine[0]=='#')  //comment line, so read another.
		{
			myFile.ReadString (strLine);	
		}

	}	// while

}	// ReaddHsvdData

int CHighSpeedVideoData::CountPipes(CString &strLine)
{
	int nPipes = 0;
	int nLoc = strLine.Find ('|', 0);  // Find first pipe

	while (nLoc!=-1)
	{
		nPipes++;
		nLoc = strLine.Find ('|', nLoc+1);  // Find next pipe
	}

	return nPipes;
}

const CString CHighSpeedVideoData::GetTextBetweenPipes(CString &strLine, const int nBegin, const int nEnd)
{
	if ((nBegin < 0) || (nEnd <= nBegin))
	{
		return "";   // bad beginning or end
	}

	int loc1,loc2;
	loc1 = loc2 = 0;

	if (nBegin==0)  // loc1 before first pipe.
	{
		if (strLine[0]=='|') { return ""; } // Y. Wong added in 06/14/00

		loc1 = 0;
		loc2 = strLine.Find ('|',loc1+1); //loc2 now has first pipe location
	
		int loop,temp;
		for (loop=1; loop < nEnd; loop++) //advance loc2 to nEnd
		{
			temp = loc2;
			loc2 = strLine.Find ('|', temp+1);

		}

		if (loc2 !=-1)  //valid loc
		{
			CString strRet = strLine.Mid (0, loc2);	
			return strRet;
		}
		else  // This is for the last data in a line, not bound by a |.  
		{
			return strLine;
		}
	
	}
	else  // put loc1 at nBegin
	{
		loc1 = strLine.Find ('|',0);  // loc1 now has first pipe location
		loc2 = strLine.Find ('|',loc1+1); //loc2 now has second pipe location
		
		int loop;
		for (loop=1; loop < nBegin; loop++) //advance loc1 to nBegin
		{
			loc1 = loc2;
			loc2 = strLine.Find ('|', loc1+1);

		}
		loop++; // advance the loop, nEnd starts at 2.
		int temp = loc1;
		for (;loop < nEnd; loop++)  // advance loc2 to nEnd
		{
			temp = loc2;
			loc2 = strLine.Find ('|', temp+1);
		}

		if ((loc1 != -1) && (loc2 !=-1))  //valid locs
		{
			CString strRet = strLine.Mid (loc1 +1, loc2 - (loc1+1));	
			return strRet;
		}
		else  // This is for the last data in a line, not bound by a |.  
		{
			CString strRet = strLine.Mid (loc1+1, strLine.GetLength () -(loc1+1)) ;   
			return strRet;
		}
	}

}	// GetTextBetweenPipes