#include "intrusiondata.h"

CIntrusionData::CIntrusionData(void)
{
	ClearIntrusionData();
}

CIntrusionData::~CIntrusionData(void)
{
}

void CIntrusionData::SetTestRef( const CString sTstRef )
{
	m_tstref = sTstRef;
}	// 

void CIntrusionData::ClearIntrusionData()
{
	m_nrt_no.RemoveAll();
	m_nrt_vehno.RemoveAll();
//	m_nrt_point.RemoveAll();
	m_nrt_pointno.RemoveAll();
	m_nrt_pointloc.RemoveAll();
	m_nrt_bix.RemoveAll();
	m_nrt_biy.RemoveAll();
	m_nrt_biz.RemoveAll();
	m_nrt_aix.RemoveAll();
	m_nrt_aiy.RemoveAll();
	m_nrt_aiz.RemoveAll();

	m_nrt_no.SetAtGrow( 0, "" );
	m_nrt_vehno.SetAtGrow( 0, "1" );
//	m_nrt_point.SetAtGrow( 0, "" );
	m_nrt_pointno.SetAtGrow( 0, "" );
	m_nrt_pointloc.SetAtGrow( 0, "" );
	m_nrt_bix.SetAtGrow( 0, "" );
	m_nrt_biy.SetAtGrow( 0, "" );
	m_nrt_biz.SetAtGrow( 0, "" );
	m_nrt_aix.SetAtGrow( 0, "" );
	m_nrt_aiy.SetAtGrow( 0, "" );
	m_nrt_aiz.SetAtGrow( 0, "" );

}	// ClearIntrusionData

bool CIntrusionData::ImportIntrusion(CString& strfile_in, bool bErrMsgResponse /*=true*/)
{
	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_in, CFile::modeRead | CFile::typeText,
		&fileException );

	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		if (bErrMsgResponse)
		{
			CString msg;
			msg.Format ("Can't open file %s, error = %u\n", strfile_in, fileException.m_cause );
			MessageBox(NULL,msg,"Error",MB_OK);
		}
		return FALSE;
	}

	ReadIntrusionData(myFile);
	
	myFile.Close ();
	return true;
}	// ImportIntrusion

void CIntrusionData::WriteIntrusionReport (CStdioFile& myFile)
{
	if( m_nrt_pointno.GetSize() == 1 ) { return; }

	myFile.WriteString ("----- INTRUSION -----\n");

	for( int i = 1; i < m_nrt_pointno.GetSize(); i++ )  
	{
		myFile.WriteString ("----- INTRUSION POINT " + m_nrt_no[i] + " -----\n");
		myFile.WriteString ("Test reference:		" + m_tstref + "\n");
		myFile.WriteString ("Vehicle number:		" + m_nrt_vehno[i] + "\n");
		myFile.WriteString ("Intrusion point number:" + m_nrt_pointno[i] + "\n");
		myFile.WriteString ("Intrusion point location:" + m_nrt_pointloc[i] + "\n");
		myFile.WriteString ("Before intrusion x:	" + m_nrt_bix[i] + "\n");
		myFile.WriteString ("Before intrusion y:	" + m_nrt_biy[i] + "\n");
		myFile.WriteString ("Before intrusion z:	" + m_nrt_biz[i] + "\n");
		myFile.WriteString ("After intrusion x:	" + m_nrt_aix[i] + "\n");
		myFile.WriteString ("After intrusion y:	" + m_nrt_aiy[i] + "\n");
		myFile.WriteString ("After intrusion z:	" + m_nrt_aiz[i] + "\n");
	}
}	// WriteIntrusionReport

bool CIntrusionData::ExportIntrusion(CString& strfile_out)
{
	if( m_nrt_pointno.GetSize() == 1 ) { return false; }

	CStdioFile myFile;
	CFileException fileException;

	myFile.Open(	strfile_out,
					CFile::modeCreate | CFile::modeReadWrite | CFile::typeText,
					&fileException );

	if( !myFile.m_pStream )  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return false;
	}
	
	CTime now = CTime::GetCurrentTime ();
	myFile.WriteString ("# Source: Intrusion Data\n");
	CString strToday;
	strToday.Format("# Date: <%d/%d/%d>\n", now.GetMonth(), now.GetDay(), now.GetYear() );
	myFile.WriteString (strToday);
	
	WriteIntrusion(myFile);
	myFile.WriteString ("----- END -----\n");

	myFile.Close ();

	return true;
}	// ExportIntrusion

bool CIntrusionData::ExportIntrusionReport(CString& strfile_out)
{
	if( m_nrt_pointno.GetSize() == 1 ) { return false; }

	CStdioFile myFile;
	CFileException fileException;

	myFile.Open(	strfile_out,
					CFile::modeCreate | CFile::modeReadWrite | CFile::typeText,
					&fileException );

	if( !myFile.m_pStream )  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return false;
	}
	
	CTime now = CTime::GetCurrentTime ();
	myFile.WriteString ("# Source: Intrusion Data\n");
	CString strToday;
	strToday.Format("# Date: <%d/%d/%d>\n", now.GetMonth(), now.GetDay(), now.GetYear() );
	myFile.WriteString (strToday);
	
	WriteIntrusionReport(myFile);
	myFile.WriteString ("----- END -----\n");
	myFile.Close ();

	return true;
}	// ExportIntrusionReport

bool CIntrusionData::ValidateEmptyIntrusion()
{
	if (m_nrt_pointno.GetSize()==1) { return false; }
	return true;
}	// ValidateEmptyIntrusion

// private functions:
const CString CIntrusionData::OutString(CString& st)
{
	CString str = st;
	if (str=="") { str=" |"; }
	else { str+= "|"; }
	
	return str;
}

const CString CIntrusionData::RemoveReturn(const CString  st)
{
	CString str = st;
	str.Remove('\n'); 
	str.Remove('\r');
	
	return str;
}

void CIntrusionData::WriteIntrusion(CStdioFile& myFile)
{

	myFile.WriteString ("----- INTRUSION -----\n");

	CString sLine = "";
	int n = m_nrt_pointno.GetSize();
	for( int i = 1; i < n; i++ )  
	{
		sLine = OutString(m_nrt_no[i]);
		sLine+= OutString(m_tstref);
		sLine+= OutString(m_nrt_vehno[i]);
		sLine+= OutString(m_nrt_pointno[i]);
		sLine+= OutString(m_nrt_pointloc[i]);
		sLine+= OutString(m_nrt_bix[i]);
		sLine+= OutString(m_nrt_biy[i]);
		sLine+= OutString(m_nrt_biz[i]);
		sLine+= OutString(m_nrt_aix[i]);
		sLine+= OutString(m_nrt_aiy[i]);
		sLine+= OutString(m_nrt_aiz[i]);
	}

}	// WriteIntrusion

void CIntrusionData::ReadIntrusionData(CStdioFile& myFile)
{
	CString strLine;
	myFile.SeekToBegin ();  // back to beginning

	// find ----- HSVD -----
	int nRes = -1;
	while (myFile.ReadString (strLine))
	{
		nRes = strLine.Find("----- INTRUSION -----");
		if (nRes != -1) break;
	}

	if (nRes==-1)  { return; } //  not found.

    // now read line after ----- HSVD -----
	myFile.ReadString (strLine);	

//	if ((strLine.GetLength ()) <1) 
//	{
//		return;  // don't process empty string
//	}

	while ((strLine[0]=='#')||(strLine.GetLength()<1))  //comment line, so read another.
	{
		myFile.ReadString (strLine);	
	}

	int loc1 = strLine.Find ('|',0);
	if (loc1==-1) 
	{
		return;      // | not found in line after ----- HSVD -----,
				     // must be another section, so return.
	}

	int loop = 1;
	while ((strLine.Find("----- END -----"))== -1)  // not at end line.
	{
		int nPipes = CountPipes(strLine);

		if (nPipes!= 10)
		{
			char buf [10];
			itoa (nPipes,buf,10);
			CString strPipes = buf;
			CString strErr = "This file has "+strPipes +" | characters in one line of the HSVD section, should have 10.";
			MessageBox(NULL, strErr, "Error",MB_OK);
			return;  // makes sure all entries are correct.
		}
		// ClearIntrusionData(); // used this will lose data
		// GetTextBetweenPipes is fragile. if an index i is used it cannot work correctly in release version
		char szN[4]; itoa(loop, szN, 10);
		m_nrt_no.SetAtGrow(loop, szN);
		CString temp = GetTextBetweenPipes(strLine, 1, 2);
		m_tstref = temp; 
		temp = GetTextBetweenPipes(strLine, 2, 3);
		m_nrt_vehno.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 3, 4);
		m_nrt_pointno.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 4, 5);
		m_nrt_pointloc.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 5, 6);
		m_nrt_bix.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 6, 7);
		m_nrt_biy.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 7, 8);
		m_nrt_biz.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 8, 9);
		m_nrt_aix.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 9, 10);
		m_nrt_aiy.SetAtGrow(loop, temp);
		temp = GetTextBetweenPipes(strLine, 10, 11);
		m_nrt_aiz.SetAtGrow(loop, temp);
		
		loop++;

		myFile.ReadString (strLine);

		while (strLine[0]=='#')  //comment line, so read another.
		{
			myFile.ReadString (strLine);	
		}
	}	// while

}	// ReaddIntrusionData

void CIntrusionData::GetIntrPtAndLoc(const CString nrt_pointno, CString& nrt_point, CString& nrt_pointloc)
{
	//  data base needed
}	// GetIntrPtAndLoc

int CIntrusionData::CountPipes(CString &strLine)
{
	int nPipes = 0;
	int nLoc = strLine.Find ('|', 0);  // Find first pipe

	while (nLoc!=-1)
	{
		nPipes++;
		nLoc = strLine.Find ('|', nLoc+1);  // Find next pipe
	}

	return nPipes;
}

CString CIntrusionData::GetTextBetweenPipes(CString &strLine, int nBegin, int nEnd)
{
	if ((nBegin < 0) || (nEnd <= nBegin))
	{
		return "";   // bad beginning or end
	}

	int loc1,loc2;
	loc1 = loc2 = 0;

	if (nBegin==0)  // loc1 before first pipe.
	{
		if (strLine[0]=='|') { return ""; } // Y. Wong added in 06/14/00

		loc1 = 0;
		loc2 = strLine.Find ('|',loc1+1); //loc2 now has first pipe location
	
		int loop,temp;
		for (loop=1; loop < nEnd; loop++) //advance loc2 to nEnd
		{
			temp = loc2;
			loc2 = strLine.Find ('|', temp+1);

		}

		if (loc2 !=-1)  //valid loc
		{
			CString strRet = strLine.Mid (0, loc2);	
			return strRet;
		}
		else  // This is for the last data in a line, not bound by a |.  
		{
			return strLine;
		}
	
	}
	else  // put loc1 at nBegin
	{
		loc1 = strLine.Find ('|',0);  // loc1 now has first pipe location
		loc2 = strLine.Find ('|',loc1+1); //loc2 now has second pipe location
		
		int loop;
		for (loop=1; loop < nBegin; loop++) //advance loc1 to nBegin
		{
			loc1 = loc2;
			loc2 = strLine.Find ('|', loc1+1);

		}
		loop++; // advance the loop, nEnd starts at 2.
		int temp = loc1;
		for (;loop < nEnd; loop++)  // advance loc2 to nEnd
		{
			temp = loc2;
			loc2 = strLine.Find ('|', temp+1);
		}

		if ((loc1 != -1) && (loc2 !=-1))  //valid locs
		{
			CString strRet = strLine.Mid (loc1 +1, loc2 - (loc1+1));	
			return strRet;
		}
		else  // This is for the last data in a line, not bound by a |.  
		{
			CString strRet = strLine.Mid (loc1+1, strLine.GetLength () -(loc1+1)) ;   
			return strRet;
		}
	}

}	// GetTextBetweenPipes