// BioData.h: interface for the CBioData class.
//
//////////////////////////////////////////////////////////////////////

#include "BioGR1.h"
#include "BioGR5.h"
#include "BioGR6.h"
#include "BioGR7.h"
#include "BioGR8.h"
#include "BioGRY.h"
#include "BioGRZ.h"
#include "HighSpeedVideoData.h"

#if !defined(AFX_BIODATA_H__D1CF0E03_6F35_11D2_9496_0008C7AA9033__INCLUDED_)
#define AFX_BIODATA_H__D1CF0E03_6F35_11D2_9496_0008C7AA9033__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000


class CBioData : public CHighSpeedVideoData
{
public:
	// Constructors/Destructors
	CBioData();
	virtual ~CBioData();

	// member funcs
	const CString IntString(PCSTR sStr);
	const CString NumberString(PCSTR sStr);
	void ExtractDumDataFromEV4(CStdioFile&);
	short ImportGRZ(CString &);
	short ImportGRY (CString &);
	short ImportGR8(CString &);
	BOOL ImportGR7(CString &);
	BOOL ImportGR6(CString &);
	BOOL ImportGR5(CString&);
	BOOL ImportGR1(CString &);
	BOOL IsEV4BioOcc(CStdioFile &, const CString sSection);
	void ExtractOccDataFromEV4(CStdioFile & myFile);
	void ExtractRibDataFromBOcc (CStdioFile &);
	BOOL LoadBioEV4Data(CStdioFile &);
	void ExtractAnthData (CStdioFile &, int);
	void ExtractCBandData (CStdioFile &, int);
	void ExtractDumData (CStdioFile &);
	void ExtractGaugeData (CStdioFile &, int);
	void ExtractInjData (CStdioFile &, int);
	void ExtractInstData (CStdioFile &, int);
	void ExtractOccData (CStdioFile &);
	void ExtractRestData (CStdioFile &, int);
	void ExtractRibData (CStdioFile &);
	void ExtractTestData(CStdioFile &, int);
	BOOL LoadBioEV5Data(CStdioFile &);
	BOOL ImportEV4(CString &);
	BOOL ImportEV5 (CString &);
	void WriteBioRibReport (CStdioFile &);
	void WriteBioRestReport (CStdioFile &);
	void WriteBioOccReport (CStdioFile &);
	void WriteBioMechTestReport (CStdioFile &);
	void WriteBioInstReport (CStdioFile &);
	void WriteBioInjReport (CStdioFile &);
	void WriteBioGaugeReport (CStdioFile &);
	void WriteBioDumReport (CStdioFile &);
	void WriteBioCBandReport(CStdioFile &);
	void WriteBioAnthReport(CStdioFile &);
	BOOL ExportEVR(CString &);
	inline CString OutString(int);
	inline CString OutString (CString);
	inline CString OutString (double, short);
	inline CString OutString (DWORD);
	void WriteBioRib(CStdioFile &);
	void WriteBioRest (CStdioFile &);
	void WriteBioOcc(CStdioFile &);
	void WriteBioTest(CStdioFile &);
	void WriteBioInst(CStdioFile &); 
	void WriteBioInj(CStdioFile &);
	void WriteBioGauge(CStdioFile &);
	void WriteBioDum(CStdioFile &);
	void WriteBioCBand (CStdioFile &);
	void WriteBioAnth(CStdioFile &);
	BOOL ExportEV5(CString &);


	// data members
public:
	
	CBioGR1 m_GR1;
	CBioGR5 m_GR5;
	CBioGR6 m_GR6;
	CBioGR7 m_GR7;
	CBioGR8 m_GR8;
	CBioGRY m_GRY;
	CBioGRZ m_GRZ;

	//Test Info Data
	CString m_verno;
	CString m_title;
	CString m_tstobj;
	CString m_tstdat;
	CString m_tstprf;
	CString m_conno;
	//	CString m_tstref;	// defined in CHighSpeedVideo
	CString m_tstcfn;
	CString m_temp;
	CString m_rectyp;
	CString m_link;
	CString m_clsspd;
	CString m_impang;
	int		m_totcrv;
	CString m_occtyp;
	CString m_tstcom;
	//Dummy Occupant Info Data
	CString m_doccloc;
	CString m_doccsex;
	CString m_dseposn;
	CString m_hic;
	CString m_t1;	// double
	CString m_t2;	// double
	CString m_clip3m;	// double
	CString m_lfem;
	CString m_rfem;
	CString m_csi;
	CString m_lbelt;
	CString m_sbelt;
	CString m_tti;	// double
	CString m_pelvg;	// double
	CString m_cti;	// float
	CString m_vc;	// float
	CString m_cmax;
	CString m_nij;	// float
	CString m_mthcal;
	CString m_dumsiz;
	CString m_dumman;
	CString m_dummod;
	CString m_dumdsc;
	CString m_dcompwt;
	CString m_doccom;
	//Bio Specimen Occupant Info Data
	CString m_boccloc;
	CString	m_boccsex; 
	CString m_bseposn;
	CString m_occage;
	CString m_occwt;
	CString m_frctrb;
	CString m_rbfrct;
	CString m_occref;
	CString m_notest;
	CString m_dtedth;
	CString m_csedth;
	CString m_cadapp;
	CString m_bedcon;
	CString m_cadan;
	CString m_aorpre;
	CString m_cerpre;
	CString m_pulpre;
	CString m_boccom;
	CString m_bmc;
	CString m_bmcloc;
	CString m_bmcunits;
	CString m_bmcmethod;
	CString m_bcompwt;
	CString m_bmccom;
	//Bio Anthropometric Info Data
	CString		m_statur;
	CString		m_shldht;
	CString		m_vrtsym;
	CString		m_wastht;
	CString		m_shldbd;
	CString		m_chstbd;
	CString		m_wastbd;
	CString		m_hipbd;
	CString		m_shldel;
	CString		m_farmhd;
	CString		m_tiblht;
	CString		m_anklht;
	CString		m_footbd;
	CString		m_footln;
	CString		m_hdtroc;
	CString		m_seatht;
	CString		m_kneeht;
	CString		m_headln;
	CString		m_headbd;
	CString		m_headch;
	CString		m_bicpcr;
	CString		m_elbwcr;
	CString		m_farmcr;
	CString		m_wrstcr;
	CString		m_thghcr;
	CString		m_ltghcr;
	CString		m_kneecr;
	CString		m_calfcr;
	CString		m_anklcr;
	CString		m_neckcr;
	CString		m_scyecr;
	CString		m_chstcr;
	CString		m_wastcr;
	CString		m_buttcr;
	CString		m_chstdp;
	CString		m_wastdp;
	CString		m_buttdp;
	CString		m_inscye;
    //Bio Rib Info Data
	int     m_ribno;
	CStringArray  m_ribloc;
	CStringArray  m_ribin;
	CStringArray  m_nadis;
	CStringArray  m_splen;
	CStringArray  m_defl;
	CStringArray  m_load;
	CStringArray  m_brkld;
	CStringArray  m_armar;
	CStringArray  m_rarea;
	//Bio Occupant Injury Information
	int      m_injno;
	CStringArray m_bodyrg;
	CStringArray m_aspect;
	CStringArray m_lesion;
	CStringArray m_sysorg;
	CStringArray m_ais;
	CStringArray m_ais90; // CArray<double,double> m_ais90;
	CStringArray m_injcom;
	//Bio Occupant Restraints Information
	int  m_rstno;
	CStringArray m_rsttyp;
	CStringArray m_rstmnt;
	CStringArray m_deploy;
	CStringArray m_rstcom;
	//Bio ChestBand Occupant Information
	int  m_bandno;
	CStringArray	m_chsdpt;
	CStringArray	m_chsbrd; 
	CStringArray	m_banlen; 
	CStringArray	m_antloc;
	CStringArray	m_posloc;
	CStringArray	m_gagstr;
	CStringArray	m_disstr;
	CStringArray	m_gagspn;
	CStringArray	m_disspn;
	CStringArray	m_totgag;
	CStringArray	m_chbcom;
	//Bio Chest Band Gauge Information
	int m_gaugesets;
	CStringArray	m_Gauge_bandno;
	CStringArray	m_gageno;
	CStringArray	m_gagdis;
	CStringArray	m_Gauge_curno;
	CStringArray	m_gagcom;
	//Bio Instrumentation Information
	int  m_curno;
	CStringArray m_sentyp;
	CStringArray m_senloc;
	CStringArray m_senatt;
	CStringArray m_axis;
	CStringArray m_xunits;
	CStringArray m_yunits;
	CStringArray m_prefil;
	CStringArray m_insman;
	CStringArray m_caldat;
	CStringArray m_insrat;	// CArray<int,int> m_insrat;
	CStringArray m_chlmax;
	CStringArray m_inivel;	// CArray<float,float> m_inivel;
	CStringArray m_nfp;	// CArray<int,int> m_nfp;
	CStringArray m_nlp;	// CArray<int,int> m_nlp;
	CStringArray m_delt;
	CStringArray m_dastat;
	CStringArray m_chstat;
	CStringArray m_inscom;

	bool	ValidateDoccData();
	bool	ValidateSoccData();

private:
	bool	ValidateTestData();
//	bool	ValidateDoccData();
//	bool	ValidateSoccData();
	bool	ValidateAnthData();
	bool	ValidateRibData();
	bool	ValidateInjData();
	bool	ValidateRestData();
	bool	ValidateBandData();
	bool	ValidateGageData();
	bool	ValidateInstData();

};

#endif // !defined(AFX_BIODATA_H__D1CF0E03_6F35_11D2_9496_0008C7AA9033__INCLUDED_)
