// -----------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: BioGaugePage.cpp
//
// Author: Dan Robbins
//
// Date Created: October, 1998
//
// Description:  Member functions of CBioGaugePage.
//               They relate to the loading and display of 
//               data on this page.
//
//  Modification History:
//  Date		Who			Description
//	2000    Y. Wong Adding business rules, recode all edit boxs
//					and correct other errors.
// -----------------------------------------

#include "stdafx.h"
#include "entreeV5.h"
#include "BioGaugePage.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CBioGaugePage property page

IMPLEMENT_DYNCREATE(CBioGaugePage, CPropertyPage)

CBioGaugePage::CBioGaugePage() : CPropertyPage(CBioGaugePage::IDD)
{
	//{{AFX_DATA_INIT(CBioGaugePage)
	m_retaindata = FALSE;
	m_editgagcom = _T("");
	m_editbandno = _T("");
	m_editgageno = _T("");
	m_editgagdis = _T("");
	m_editcurno = _T("");
	//}}AFX_DATA_INIT

	m_curset = 0;
}

CBioGaugePage::~CBioGaugePage()
{
}

void CBioGaugePage::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CBioGaugePage)
	DDX_Control(pDX, IDC_GAUGELIST, m_gaugelist);
	DDX_Control(pDX, IDC_NEXTSET_BUTTON, m_nextsetbutton);
	DDX_Control(pDX, IDC_DELETE_BUTTON, m_deletebutton);
	DDX_Check(pDX, IDC_RETAINDATA, m_retaindata);
	DDX_Control(pDX, IDC_BIOGAUGE_GAGCOM, m_editgagcom);
///	DDV_MaxChars(pDX, m_gagcom, 70);
	DDX_Control(pDX, IDC_BIOGAUGE_BANDNO, m_editbandno);
//	DDV_MinMaxDWord(pDX, m_bandno, 1, 5);
	DDX_Control(pDX, IDC_BIOGAUGE_GAGENO, m_editgageno);
//	DDV_MinMaxDWord(pDX, m_gageno, 1, 40);
	DDX_Control(pDX, IDC_BIOGAUGE_GAGDIS, m_editgagdis);
//	DDV_MinMaxDWord(pDX, m_gagdis, 0, 999);
	DDX_Control(pDX, IDC_BIOGAUGE_CURNO, m_editcurno);
//	DDV_MinMaxDWord(pDX, m_curno, 1, 200);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CBioGaugePage, CPropertyPage)
	//{{AFX_MSG_MAP(CBioGaugePage)
	ON_BN_CLICKED(IDC_NEXTSET_BUTTON, OnNextsetButton)
	ON_BN_CLICKED(IDC_DELETE_BUTTON, OnDeleteButton)
	ON_LBN_SELCHANGE(IDC_GAUGELIST, OnSelchangeGaugelist)
	ON_NOTIFY_EX_RANGE( TTN_NEEDTEXTW, 0, 0xFFFF, OnToolTipNotify )
	ON_NOTIFY_EX_RANGE( TTN_NEEDTEXTA, 0, 0xFFFF, OnToolTipNotify )
	ON_WM_HELPINFO()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CBioGaugePage message handlers

BOOL CBioGaugePage::OnToolTipNotify( UINT id, NMHDR * pNMHDR, LRESULT * pResult )
{
	TOOLTIPTEXTA* pTTTA = (TOOLTIPTEXTA*)pNMHDR;
	TOOLTIPTEXTW* pTTTW = (TOOLTIPTEXTW*)pNMHDR;
	CString strTipText = "";
	UINT nID = pNMHDR->idFrom;
	if (pNMHDR->code == TTN_NEEDTEXTA && (pTTTA->uFlags & TTF_IDISHWND) ||
		pNMHDR->code == TTN_NEEDTEXTW && (pTTTW->uFlags & TTF_IDISHWND))
	{
		// idFrom is actually the HWND of the tool
		nID = ::GetDlgCtrlID((HWND)nID);
	}

	if (nID != 0) // will be zero on a separator
	{
		strTipText.Format("Control ID = %d", nID);
		switch (nID)
			{
			case IDC_NEXTSET_BUTTON:
				strTipText = "Go to or add next gauge info set";
				break;
			case IDC_BIOGAUGE_GAGDIS:
				strTipText = "Millimeters (0->1800)";
				break;
			case IDC_BIOGAUGE_BANDNO:
				strTipText = "1->5";
				break;
			case IDC_BIOGAUGE_GAGENO:
				strTipText = "0->1000";
				break;
			case IDC_BIOGAUGE_CURNO:
				strTipText = "1->200";
				break;
			case IDC_DELETE_BUTTON:
				strTipText = "Delete gauge info set";
				break;
			default:
				strTipText = "";
			}
	}

	if (pNMHDR->code == TTN_NEEDTEXTA)
		lstrcpyn(pTTTA->szText, strTipText, sizeof(pTTTA->szText));
	else
		::MultiByteToWideChar( CP_ACP , 0, strTipText, -1, pTTTW->szText, sizeof(pTTTW->szText) );
	*pResult = 0;

	return TRUE;    // message was handled
}

BOOL CBioGaugePage::OnKillActive() 
{
	if( ValidateGaugePage() == true )
	{
		LoadBioGaugeData();

		int nOldCurIndx = m_curset;
//		for (m_curset=1; m_curset<m_pBioData->m_gaugesets+1; m_curset++)
		for( m_curset = 1; m_curset < m_settot + 1; m_curset++ )
		{
			DisplayBioGaugeData();
			if (!ValidateGaugePage()) { return false; }
		}
		m_curset = nOldCurIndx;

		DisplayBioGaugeData();

		return CPropertyPage::OnKillActive();
	}
	else
	{
		// Error are found on AnthPage.
		return FALSE;
	}
}

BOOL CBioGaugePage::OnSetActive() 
{
	m_settot=max(m_pBioData->m_gaugesets , 0) ; //initialize total curves.

	SetBusinessRules();

	DisplayBioGaugeData();

	ValidateGaugePage();
	
	return CPropertyPage::OnSetActive();
}

BOOL CBioGaugePage::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	EnableToolTips();

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

//  This function gets the data from the entry fields and puts it into 
//  m_pBioData.  It is called in OnKillActive, ExportData, record changed.
BOOL CBioGaugePage::LoadBioGaugeData()
{
	if (m_hWnd==NULL) return TRUE; // only return FALSE if data invalid
	if (!UpdateData(TRUE)) return FALSE;

	//put data into m_pBioData
	m_pBioData->m_Gauge_bandno[m_curset] = m_editbandno.GetTextAsString();
	m_pBioData->m_Gauge_curno[m_curset] = m_editcurno.GetTextAsString();
	m_pBioData->m_gagcom[m_curset] = m_editgagcom.GetTextAsString();
	m_pBioData->m_gagdis[m_curset] = m_editgagdis.GetTextAsString();
	m_pBioData->m_gageno[m_curset] = m_editgageno.GetTextAsString();
	
	m_pBioData->m_gaugesets = m_settot;

	return TRUE;

}

// wong code in 03/02/00
bool CBioGaugePage::InsertBioGaugeData()
{
	if (m_hWnd==NULL) return TRUE;  // only return FALSE if data invalid
	
	UpdateData();
 
//	m_pBioData->m_ais.InsertAt( m_curinj, m_ais);
	m_pBioData->m_Gauge_bandno.InsertAt( m_curset, m_editbandno.GetTextAsString() );
	m_pBioData->m_Gauge_curno.InsertAt( m_curset, m_editcurno.GetTextAsString() );
	m_pBioData->m_gagcom.InsertAt( m_curset, m_editgagcom.GetTextAsString() );
	m_pBioData->m_gagdis.InsertAt( m_curset, m_editgagdis.GetTextAsString() );
	m_pBioData->m_gageno.InsertAt( m_curset, m_editgageno.GetTextAsString() );
	
	m_pBioData->m_gaugesets = m_settot;

	UpdateData(false);

	return true;
}	// InsertBioGaugeData

//Get data from m_pBioData and display it.
void CBioGaugePage::DisplayBioGaugeData()
{
	if( m_hWnd==NULL ) return;

	UpdateCurveListbox();

	UpdateData();
	m_editbandno	= m_pBioData->m_Gauge_bandno[m_curset];
	m_editcurno		= m_pBioData->m_Gauge_curno[m_curset];
	m_editgagcom	= m_pBioData->m_gagcom[m_curset];
	m_editgagdis	= m_pBioData->m_gagdis[m_curset];
	m_editgageno	= m_pBioData->m_gageno[m_curset];

	UpdateData(FALSE);

}

void CBioGaugePage::OnNextsetButton() 
{
	if (::GetKeyState(VK_RETURN)<0) { return; }

	if (m_curset==m_settot) //if at end, increase # of curves
	{
		if (m_curset!=0) { LoadBioGaugeData(); }
		m_settot++; 
		m_curset++;
		InitializeNextSet();
	} 
	else if (m_curset != 0) 
	{
		if(!LoadBioGaugeData())
		{
			MessageBox("Error: see CBioGaugePage::OnNextcurveButton()");
			return;
		}
		m_curset++;
	}

	DisplayBioGaugeData();
	SetBusinessRules( );

}

void CBioGaugePage::OnDeleteButton() 
{
	if (::GetKeyState(VK_RETURN)<0) { return; }

	if (m_curset==0) { return;  }

	m_settot--;
	// Remove the data from all of the arrays.
	m_pBioData->m_Gauge_bandno.RemoveAt(m_curset);
	m_pBioData->m_Gauge_curno.RemoveAt (m_curset);
	m_pBioData->m_gagcom.RemoveAt (m_curset);
	m_pBioData->m_gagdis.RemoveAt (m_curset);
	m_pBioData->m_gageno.RemoveAt (m_curset);

	m_curset--;

	//if m_curset == 0 now, and there are remaining curves, set curve 1 as active (m_curset=1)
	if (m_curset==0 && m_settot>0)
	{
		m_curset = 1;
	}
	
	DisplayBioGaugeData();  //display previous set, if existing
	
}

// New Gauge set, so expand arrays in m_pBioData to hold info.
void CBioGaugePage::InitializeNextSet()
{
// *******************************************
//These temp variables are used because the reference that [] returns is invalid when SetAtGrow
// happens, because SetAtGrow (sometimes) moves the array to a different location in memory.   
// If you try to use that reference directly, you will get an access violation.
// For Example:  m_pBioData->m_inscom.SetAtGrow (m_icurno,m_pBioData->inscom[m_icurno-1]); //BAD!!!!
	CString		strtemp; 
	CString		dwtemp; // DWORD   dwtemp;    
// *******************************************

	if (m_retaindata)
	{
		dwtemp = m_pBioData->m_Gauge_bandno[m_curset-1];
		m_pBioData->m_Gauge_bandno.SetAtGrow(m_curset,dwtemp);

		dwtemp = m_pBioData->m_Gauge_curno[m_curset-1];
		m_pBioData->m_Gauge_curno.SetAtGrow (m_curset,dwtemp);

		strtemp = m_pBioData->m_gagcom[m_curset-1];
		m_pBioData->m_gagcom.SetAtGrow (m_curset,strtemp);

		dwtemp = m_pBioData->m_gagdis[m_curset-1];
		m_pBioData->m_gagdis.SetAtGrow (m_curset,dwtemp);

		dwtemp = m_pBioData->m_gageno[m_curset-1];
		m_pBioData->m_gageno.SetAtGrow (m_curset,dwtemp);

	}
	else
	{
		m_pBioData->m_Gauge_bandno.SetAtGrow(m_curset, "");
		m_pBioData->m_Gauge_curno.SetAtGrow (m_curset, "");
		m_pBioData->m_gagcom.SetAtGrow (m_curset, "");
		m_pBioData->m_gagdis.SetAtGrow (m_curset, "");
		m_pBioData->m_gageno.SetAtGrow (m_curset, "");
	}
}

void CBioGaugePage::UpdateCurveListbox()
{
	if( m_gaugelist.GetCount() != m_settot )
	{
		m_gaugelist.ResetContent();
		char crvbuf [10];

		for( int loop = 1; loop <= m_settot; loop++ )
		{
			itoa( loop, crvbuf, 10 );

			// if buf isnt there already.
			if( m_gaugelist.FindString( -1, crvbuf ) == LB_ERR )  
			{
				m_gaugelist.AddString( crvbuf );
			}
		}
	}

	// select current curve, zero based.
	m_gaugelist.SetCurSel( max( 0, m_curset - 1 ) );  
	
}

void CBioGaugePage::OnSelchangeGaugelist() 
{
	int nCurve = m_gaugelist.GetCurSel ();  //zero based

	if (m_curset != 0) 
	{
		BOOL success = LoadBioGaugeData();     //load current info (not zeroth curve)
		if (!success) //Data not valid, dont change curves.
		{
			m_gaugelist.SetCurSel (max(0,m_curset-1));  // select current curve, zero based.
			return;
		}
	}

	m_curset= nCurve+1;             //goto current curve 

	DisplayBioGaugeData();  //display next set, if existing	
	SetBusinessRules( );
}

BOOL CBioGaugePage::OnHelpInfo(HELPINFO* pHelpInfo) 
{
	WinHelp( Gauge_Information);
	
	return TRUE;
}

// new  added
//
bool CBioGaugePage::ValidateGaugePage( )
{
	bool bRetArray[5];
	bRetArray[0] = m_editgagcom.GetValidate();
	bRetArray[1] = m_editbandno.GetValidate();
	bRetArray[2] = m_editgageno.GetValidate();
	bRetArray[3] = m_editgagdis.GetValidate();
	bRetArray[4] = m_editcurno.GetValidate();
	
	for(int i=0; i<5; i++) { if (!bRetArray[i]) return false; }
	return true;
}	// ValidateAnthPage

void CBioGaugePage::SetBusinessRules( )
{
	m_editgagcom.SetString( 0, 70 );
	m_editbandno.SetDouble( 0, 5 );
	m_editgageno.SetDouble( 0, 1000 );
	m_editgagdis.SetDouble( 0, 1800 );
	m_editcurno.SetDouble( 0, 200 );

}	// SetBusinessRules