// -----------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: BioGR6.cpp
//
// Author: Dan Robbins
//
// Date Created: October, 1998
//
// Description: CBioGR6 constructor.  All this class does is
//              hold the offsets and lengths used for parsing data out of
//              a GR6 file.
// -----------------------------------------
#include "stdafx.h"
#include "entreeV5.h"
#include "BioGR6.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CBioGR6::CBioGR6()
{
	 m_vehnooff = 1;
	 m_vehnolen = 1;

	 m_occlocoff = 2;
	 m_occloclen = 2;

	 m_occtypoff = 4;
	 m_occtyplen = 2;

	 m_occsexoff = 6;
	 m_occsexlen = 1;

	 m_restr1off = 7;
	 m_restr1len = 3;

	 m_restr2off = 10;
	 m_restr2len = 3;

	 m_restxtoff = 13;
	 m_restxtlen = 70;

	 m_seposnoff = 83;
	 m_seposnlen = 2;

	 m_airdepoff = 85;
	 m_airdeplen = 2;

	 m_hicoff = 87;
	 m_hiclen = 5;

	 m_t1off = 92;
	 m_t1len = 7;

	 m_t2off = 99;
	 m_t2len = 7;

	 m_mthcaloff = 106;
	 m_mthcallen = 2;

	 m_dumsizoff = 108;
	 m_dumsizlen = 2;

	 m_dummanoff = 110;
	 m_dummanlen = 70;

	 m_dummodoff = 180;
	 m_dummodlen = 70;

	 m_dumdscoff = 250;
	 m_dumdsclen = 70;

	 m_occageoff = 320;
	 m_occagelen = 2;

	 m_occwtoff = 322;
	 m_occwtlen = 3;

	 m_frctrboff = 325;
	 m_frctrblen = 2;

	 m_rbfrctoff = 327;
	 m_rbfrctlen = 2;

	 m_cadrefoff = 329;
	 m_cadreflen = 10;

	 m_notestoff = 339;
	 m_notestlen = 2;

	 m_dtedthoff = 341;
	 m_dtedthlen = 9;

	 m_csedthoff = 350;
	 m_csedthlen = 70;

	 m_cadappoff = 420;
	 m_cadapplen = 70;

	 m_bedconoff = 490;
	 m_bedconlen = 3;

	 m_cadanoff = 493;
	 m_cadanlen = 70;

	 m_aorpreoff = 563;
	 m_aorprelen = 3;

	 m_cerpreoff = 566;
	 m_cerprelen = 3;

	 m_pulpreoff = 569;
	 m_pulprelen = 3;

	 m_rib1off = 572;
	 m_rib1len = 3;

	 m_ribin1off = 575;
	 m_ribin1len = 12;

	 m_nadis1off = 587;
	 m_nadis1len = 6;

	 m_splen1off = 593;
	 m_splen1len = 6;

	 m_defl1off = 599;
	 m_defl1len = 6;

	 m_load1off = 605;
	 m_load1len = 5;

	 m_brkld1off = 610;
	 m_brkld1len = 5;

	 m_armar1off = 615;
	 m_armar1len = 6;

	 m_rarea1off = 621;
	 m_rarea1len = 6;

	 m_rib2off = 627;
	 m_rib2len = 3;

	 m_ribin2off = 630;
	 m_ribin2len = 12;

	 m_nadis2off = 642;
	 m_nadis2len = 6;

	 m_splen2off = 648;
	 m_splen2len = 6;

	 m_defl2off = 654;
	 m_defl2len = 6;

	 m_load2off = 660;
	 m_load2len = 5;

	 m_brkld2off = 665;
	 m_brkld2len = 5;

	 m_armar2off = 670;
	 m_armar2len = 6;

	 m_rarea2off = 676;
	 m_rarea2len = 6;

	 m_rib3off = 682;
	 m_rib3len = 3;

	 m_ribin3off = 685;
	 m_ribin3len = 12;

	 m_nadis3off = 697;
	 m_nadis3len = 6;

	 m_splen3off = 703;
	 m_splen3len = 6;

	 m_defl3off = 709;
	 m_defl3len = 6;

	 m_load3off = 715;
	 m_load3len = 5;

	 m_brkld3off = 720;
	 m_brkld3len = 5;

	 m_armar3off = 725;
	 m_armar3len = 6;

	 m_rarea3off = 731;
	 m_rarea3len = 6;

	 m_rib4off = 737;
	 m_rib4len = 3;

	 m_ribin4off = 740;
	 m_ribin4len = 12;

	 m_nadis4off = 752;
	 m_nadis4len = 6;

	 m_splen4off = 758;
	 m_splen4len = 6;

	 m_defl4off = 764;
	 m_defl4len = 6;

	 m_load4off = 770;
	 m_load4len = 5;

	 m_brkld4off = 775;
	 m_brkld4len = 5;

	 m_armar4off = 780;
	 m_armar4len = 6;

	 m_rarea4off = 786;
	 m_rarea4len = 6;

	 m_occcomoff = 792;
	 m_occcomlen = 70;

	 m_totallen = 862;

}

CBioGR6::~CBioGR6()
{

}
