// -----------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: BioRestPage.cpp
//
// Author: Dan Robbins
//
// Date Created: October, 1998
//
// Description:  Member functions of CBioRestPage.
//               They relate to the loading and display of 
//               data on this page.
//
//  Modification History:
//  Date		Who			Description
//	2000    Y. Wong Adding business rules, recode all edit boxs
//					and other errors.
// -----------------------------------------

#include "stdafx.h"
#include "entreeV5.h"
#include "BioRestPage.h"
#include "search.h"
#include "CodeValidation.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

extern CString search_code;

/////////////////////////////////////////////////////////////////////////////
// CBioRestPage property page

IMPLEMENT_DYNCREATE(CBioRestPage, CPropertyPage)

CBioRestPage::CBioRestPage() : CPropertyPage(CBioRestPage::IDD)
{
	//{{AFX_DATA_INIT(CBioRestPage)
	m_editdeploy = _T("");
	m_editrstcom = _T("");
	m_editrstmnt = _T("");
	m_editrsttyp = _T("");
	m_retaindata = FALSE;
	//}}AFX_DATA_INIT

	m_currest=0;
}

CBioRestPage::~CBioRestPage()
{
}

void CBioRestPage::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CBioRestPage)
	DDX_Control(pDX, IDC_RESTLIST, m_restlist);
	DDX_Control(pDX, IDC_NEXTSET_BUTTON, m_nextsetbutton);
	DDX_Control(pDX, IDC_DELETE_BUTTON, m_deletebutton);
	DDX_Control(pDX, IDC_BIORESTDEPLOY, m_editdeploy);
	DDX_Control(pDX, IDC_BIORESTRSTCOM, m_editrstcom);
//	DDV_MaxChars(pDX, m_rstcom, 70);
	DDX_Control(pDX, IDC_BIORESTRSTMNT, m_editrstmnt);
	DDX_Control(pDX, IDC_BIORESTRSTTYP, m_editrsttyp);
	DDX_Check(pDX, IDC_RETAINDATA, m_retaindata);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CBioRestPage, CPropertyPage)
	//{{AFX_MSG_MAP(CBioRestPage)
	ON_BN_CLICKED(IDC_NEXTSET_BUTTON, OnNextsetButton)
	ON_BN_CLICKED(IDC_DELETE_BUTTON, OnDeleteButton)
	ON_BN_CLICKED(IDC_DEPLOY_SEARCH, OnDeploySearch)
	ON_BN_CLICKED(IDC_RSTTYP_SEARCH, OnRsttypSearch)
	ON_BN_CLICKED(IDC_RSTMNT_SEARCH, OnRstmntSearch)
	ON_LBN_SELCHANGE(IDC_RESTLIST, OnSelchangeRestlist)
	ON_NOTIFY_EX_RANGE( TTN_NEEDTEXTW, 0, 0xFFFF, OnToolTipNotify )
	ON_NOTIFY_EX_RANGE( TTN_NEEDTEXTA, 0, 0xFFFF, OnToolTipNotify )
	ON_WM_HELPINFO()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CBioRestPage message handlers

void CBioRestPage::OnNextsetButton() 
{
	if (::GetKeyState(VK_RETURN)<0) { return; }

	if (m_currest==m_pBioData->m_rstno) //if at end, increase # of curves
	{
		if (m_currest!=0) { LoadBioRestData(); }
		m_pBioData->m_rstno++; 
		m_currest++;
		InitializeNextRest();
	} 
	else if (m_currest != 0) 
	{
		if(!LoadBioRestData())
		{
			MessageBox("Error: see CBioRestPage::OnNextcurveButton()");
			return;
		}
		m_currest++;
	}

	DisplayBioRestData();
	ValidateRestPage();
}

void CBioRestPage::OnDeleteButton() 
{
	if (::GetKeyState(VK_RETURN)<0) { return; }

	if (m_currest==0)  { return;  }

	m_pBioData->m_rstno--;

	m_pBioData->m_deploy.RemoveAt(m_currest);
	m_pBioData->m_rstcom.RemoveAt(m_currest);
	m_pBioData->m_rstmnt.RemoveAt(m_currest);
	m_pBioData->m_rsttyp.RemoveAt(m_currest);

	m_currest--;             //goto previous inj
		
	//if m_currest == 0 now, and there are remaining curves, set curve 1 as active (m_currest=1)
	if (m_currest==0 && m_pBioData->m_rstno>0)
	{
		m_currest = 1;
	}

	DisplayBioRestData();  //display previous set, if existing
	
}

void CBioRestPage::OnDeploySearch() 
{
	if (::GetKeyState(VK_RETURN)<0) { return; }

	UpdateData(TRUE);  //First save data

	CSearch search(NULL,"DEPLOY","BIODB");
	if (search.DoModal ()==IDOK)
	{
		m_editdeploy = search_code;
		m_editdeploy.SetValidateColor();
	}
	UpdateData(FALSE);		
}

void CBioRestPage::OnRsttypSearch() 
{
	if (::GetKeyState(VK_RETURN)<0) { return; }

	UpdateData(TRUE);  //First save data

	CSearch search(NULL,"RSTTYP","BIODB");
	if (search.DoModal ()==IDOK)
	{
		m_editrsttyp = search_code;
		m_editrsttyp.SetValidateColor();
	}
	UpdateData(FALSE);
	
}

void CBioRestPage::OnRstmntSearch() 
{
	if (::GetKeyState(VK_RETURN)<0) { return; }

	UpdateData(TRUE);  //First save data

	CSearch search(NULL,"RSTMNT","BIODB");
	if (search.DoModal ()==IDOK)
	{
		m_editrstmnt = search_code;
		m_editrstmnt.SetValidateColor();
	}
	UpdateData(FALSE);	
}

BOOL CBioRestPage::OnKillActive() 
{
	if( ValidateRestPage() == true )
	{
		LoadBioRestData();

		int nOldCurIndx = m_currest;
		for (m_currest=1; m_currest<m_pBioData->m_rstno+1; m_currest++)
		{
			DisplayBioRestData();
			if (!ValidateRestPage()) { return false; }
		}
		m_currest = nOldCurIndx;

		DisplayBioRestData();

		return CPropertyPage::OnKillActive();
	}
	else
	{		
		return FALSE; // Error are found on AnthPage.
	}
}

BOOL CBioRestPage::OnSetActive() 
{
//	EnableControls();
		
//	m_totalcurves=max(m_pBioData->m_injno , 0) ; //initialize total curves.

	SetBusinessRules();
	DisplayBioRestData();
	ValidateRestPage();
	
	return CPropertyPage::OnSetActive();
}

BOOL CBioRestPage::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	EnableToolTips();

	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

BOOL CBioRestPage::OnToolTipNotify( UINT id, NMHDR * pNMHDR, LRESULT * pResult )
{
	TOOLTIPTEXTA* pTTTA = (TOOLTIPTEXTA*)pNMHDR;
	TOOLTIPTEXTW* pTTTW = (TOOLTIPTEXTW*)pNMHDR;
	CString strTipText = "";
	UINT nID = pNMHDR->idFrom;
	if (pNMHDR->code == TTN_NEEDTEXTA && (pTTTA->uFlags & TTF_IDISHWND) ||
		pNMHDR->code == TTN_NEEDTEXTW && (pTTTW->uFlags & TTF_IDISHWND))
	{
		// idFrom is actually the HWND of the tool
		nID = ::GetDlgCtrlID((HWND)nID);
	}

	if (nID != 0) // will be zero on a separator
	{
		strTipText.Format("Control ID = %d", nID);
		switch (nID)
			{
			case IDC_NEXTSET_BUTTON:
				strTipText = "Go to or add next restraint info set";
				break;
			case IDC_DELETE_BUTTON:
				strTipText = "Delete restraint info set";
				break;
			case IDC_BIORESTRSTCOM:
				strTipText = "0->70";
				break;
			default:
				strTipText = "";
			}
	}

	if (pNMHDR->code == TTN_NEEDTEXTA)
		lstrcpyn(pTTTA->szText, strTipText, sizeof(pTTTA->szText));
	else
		::MultiByteToWideChar( CP_ACP , 0, strTipText, -1, pTTTW->szText, sizeof(pTTTW->szText) );
	*pResult = 0;

	return TRUE;    // message was handled
}

// This function gets data from the entry screen and puts it into m_pBioData
// It is called from OnKillActive, ExportData, and record changed.
BOOL CBioRestPage::LoadBioRestData()
{

	// put data into m_pBioData
	if (m_hWnd==NULL) return TRUE;
	if(!UpdateData(TRUE)) return FALSE;

	m_pBioData->m_deploy[m_currest] = m_editdeploy.GetTextAsString();
	m_pBioData->m_rstcom[m_currest] = m_editrstcom.GetTextAsString();
	m_pBioData->m_rstmnt[m_currest] = m_editrstmnt.GetTextAsString();
	m_pBioData->m_rstno = max(m_pBioData->m_rstno, m_currest);
	m_pBioData->m_rsttyp[m_currest] = m_editrsttyp.GetTextAsString();

	return TRUE;
		
}

// wong code in 03/02/00
bool CBioRestPage::InsertBioRestData()
{
	if (m_hWnd==NULL) return TRUE;  // only return FALSE if data invalid
	
	UpdateData();
 
	m_pBioData->m_deploy.InsertAt( m_currest, m_editdeploy.GetTextAsString() );
	m_pBioData->m_rstcom.InsertAt( m_currest, m_editrstcom.GetTextAsString() );
	m_pBioData->m_rstmnt.InsertAt( m_currest, m_editrstmnt.GetTextAsString() );
	m_pBioData->m_rstno = max(m_pBioData->m_rstno, m_currest);
	m_pBioData->m_rsttyp.InsertAt( m_currest, m_editrsttyp.GetTextAsString() );

	UpdateData(false);

	return true;
}	// InsertBioRestData

// Get data from m_pBioData and display it.
void CBioRestPage::DisplayBioRestData()
{
	if (m_hWnd==NULL) return;

	UpdateCurveListbox();
	
	UpdateData(TRUE);
	m_editdeploy = m_pBioData->m_deploy[m_currest];
	m_editrstcom = m_pBioData->m_rstcom[m_currest];
	m_editrstmnt = m_pBioData->m_rstmnt[m_currest];

	m_editrsttyp = m_pBioData->m_rsttyp[m_currest];
	
	CCodeValidation( m_editdeploy, "DEPLOY","BIODB" );
	CCodeValidation( m_editrsttyp, "RSTTYP","BIODB" );
	CCodeValidation( m_editrstmnt, "RSTMNT","BIODB" );

	UpdateData(FALSE);
}

//New rest, so expand arrays in m_pBioData to hold info
void CBioRestPage::InitializeNextRest()
{
	// *******************************************
	//These temp variables are used because the reference that [] returns is invalid when SetAtGrow
	// happens, because SetAtGrow (sometimes) moves the array to a different location in memory.   
	// If you try to use that reference directly, you will get an access violation.
	// For Example:  m_pBioData->m_injcom.SetAtGrow (m_curinj,m_pBioData->injcom[m_curinj-1]); //BAD!!!!
	CString strtemp; 

	// *******************************************

	if (m_retaindata)
	{
		strtemp = m_pBioData->m_deploy[m_currest -1];
		m_pBioData->m_deploy.SetAtGrow(m_currest, strtemp);

		strtemp = m_pBioData->m_rstcom[m_currest -1];
		m_pBioData->m_rstcom.SetAtGrow(m_currest, strtemp);

		strtemp = m_pBioData->m_rstmnt[m_currest -1];
		m_pBioData->m_rstmnt.SetAtGrow(m_currest, strtemp);

		strtemp = m_pBioData->m_rsttyp[m_currest -1];
		m_pBioData->m_rsttyp.SetAtGrow(m_currest, strtemp);

	}
	else
	{
		m_pBioData->m_deploy.SetAtGrow(m_currest, "");
		m_pBioData->m_rstcom.SetAtGrow(m_currest, "");
		m_pBioData->m_rstmnt.SetAtGrow(m_currest, "");
		m_pBioData->m_rsttyp.SetAtGrow(m_currest, "");
		
	}
}


void CBioRestPage::OnSelchangeRestlist() 
{
	int nCurve = m_restlist.GetCurSel ();  //zero based

	if (m_currest != 0) 
	{
		BOOL success = LoadBioRestData();     //load current info (not zeroth curve)
		if (!success) //Data not valid, dont change curves.
		{
			m_restlist.SetCurSel (max(0,m_currest-1));  // select current curve, zero based.
			return;
		}
	}

	m_currest = nCurve+1;             //goto current curve 

	DisplayBioRestData();  //display next set, if existing
	ValidateRestPage();
}

void CBioRestPage::UpdateCurveListbox()
{
	if (m_restlist.GetCount ()!=m_pBioData->m_rstno)
	{
		m_restlist.ResetContent();
		char crvbuf [10];
		for (int loop=1;loop <= m_pBioData->m_rstno;loop++)
		{
			itoa(loop,crvbuf,10);
			if (m_restlist.FindString (-1,crvbuf)==LB_ERR)  //if buf isnt there already.
			{
				m_restlist.AddString(crvbuf);
			}
		}
	}

	m_restlist.SetCurSel (max(0,m_currest-1));  // select current curve, zero based.	
}

BOOL CBioRestPage::OnHelpInfo(HELPINFO* pHelpInfo) 
{
	WinHelp(Restraint_Information);
	
	return TRUE;
}

//
bool CBioRestPage::ValidateRestPage()
{
	const int nTotal = 7;
	bool bRetArray[nTotal];

	bRetArray[0] = m_editrstcom.GetValidate();
	bRetArray[1] = m_editdeploy.GetValidate();
	bRetArray[2] = m_editrsttyp.GetValidate();
	bRetArray[3] = m_editrstmnt.GetValidate();

	bRetArray[4] = m_editdeploy.GetValidate();
	bRetArray[5] = m_editrsttyp.GetValidate();
	bRetArray[6] = m_editrstmnt.GetValidate();

	for(int i=0; i<nTotal; i++) { if (!bRetArray[i]) return false; }
	return true;
}	// ValidateAnthPage

void CBioRestPage::SetBusinessRules()
{
	m_editrstcom.SetString( 0, 70 );
}	// SetBusinessRules