// -----------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: ChooseDB.cpp
//
// Author: Dan Robbins
//
// Date Created: October, 1998
//
// Description:  Let the user choose which DB to start with.
//				 Then, hide the modal ChooseDB dialog, and start a modeless              
//               property sheet.  The hidden modal ChooseDB will exist until
//	             the end of the program, when one of the property sheets will call
//				 DoneChoose.
// -----------------------------------------


#include "stdafx.h"
#include "entreeV5.h"
#include "ChooseDB.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

static CComponentPropertySheet* pCompSheet=NULL;
static CVehiclePropertySheet* pVehSheet=NULL;
static CSWGPropertySheet* pSWGSheet=NULL;
static CBioMechPropertySheet* pBioSheet=NULL;

/////////////////////////////////////////////////////////////////////////////
// CChooseDB dialog


CChooseDB::CChooseDB(CWnd* pParent /*=NULL*/)
	: CDialog(CChooseDB::IDD, pParent)
{
	//{{AFX_DATA_INIT(CChooseDB)
		// NOTE: the ClassWizard will add member initialization here
	//}}AFX_DATA_INIT
}


void CChooseDB::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CChooseDB)
		// NOTE: the ClassWizard will add DDX and DDV calls here
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CChooseDB, CDialog)
	//{{AFX_MSG_MAP(CChooseDB)
	ON_BN_CLICKED(IDC_VEHICLE_BUTTON, OnVehicleButton)
	ON_BN_CLICKED(IDC_COMPONENT_BUTTON, OnComponentButton)
	ON_BN_CLICKED(IDC_SWG_BUTTON, OnSwgButton)
	ON_BN_CLICKED(IDC_BIOMECH_BUTTON, OnBiomechButton)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CChooseDB message handlers

void CChooseDB::OnVehicleButton() 
{
	ShowWindow(SW_HIDE);  // Hides the ChooseDB window.

	if (pCompSheet) 
	{
		delete pCompSheet;  //Clean up other modeless windows if they exist
		pCompSheet = NULL;
	}

	if (pSWGSheet) 
	{
		delete pSWGSheet;
		pSWGSheet =  NULL;
	}

	if (pBioSheet) 
	{
		delete pBioSheet;
		pBioSheet = NULL;
	}

	pVehSheet = new CVehiclePropertySheet("Vehicle Data", this);
	pVehSheet->Create(NULL, WS_THICKFRAME |WS_SYSMENU | WS_POPUP | WS_CAPTION | DS_MODALFRAME | WS_VISIBLE|WS_MINIMIZEBOX);
}

void CChooseDB::OnComponentButton() 
{
	ShowWindow(SW_HIDE);  // Hides the ChooseDB window.

	if (pVehSheet) 
	{
		delete pVehSheet;  //Clean up other modeless windows if they exist
		pVehSheet = NULL;
	}

	if (pSWGSheet) 
	{
		delete pSWGSheet;
		pSWGSheet = NULL;
	}

	if (pBioSheet) 
	{
		delete pBioSheet;
		pBioSheet = NULL;
	}

	pCompSheet = new CComponentPropertySheet("Component Data", this);
	pCompSheet->Create(NULL, WS_THICKFRAME |WS_SYSMENU | WS_POPUP | WS_CAPTION | DS_MODALFRAME | WS_VISIBLE|WS_MINIMIZEBOX);
}

void CChooseDB::OnSwgButton() 
{
	ShowWindow(SW_HIDE);  // Hides the ChooseDB window.

	if (pCompSheet) 
	{
		delete pCompSheet;  //Clean up other modeless windows if they exist
		pCompSheet = NULL;
	}

	if (pVehSheet) 
	{
		delete pSWGSheet;
		pSWGSheet = NULL;
	}

	if (pBioSheet) 
	{
		delete pBioSheet;
		pBioSheet = NULL;
	}

	pSWGSheet = new CSWGPropertySheet("SWG Data", this);
	pSWGSheet->Create(NULL, WS_THICKFRAME | WS_SYSMENU | WS_POPUP | WS_CAPTION | DS_MODALFRAME | WS_VISIBLE|WS_MINIMIZEBOX);
}

void CChooseDB::OnBiomechButton() 
{

	ShowWindow(SW_HIDE);  // Hides the ChooseDB window.

	if (pCompSheet)
	{
		delete pCompSheet;  //Clean up other modeless windows if they exist
		pCompSheet = NULL;
	}

	if (pSWGSheet)
	{
		delete pSWGSheet;
		pSWGSheet = NULL;
	}

	if (pVehSheet) 
	{
		delete pBioSheet;
		pBioSheet = NULL;
	}

	pBioSheet = new CBioMechPropertySheet("Biomechanics Data", this);
	pBioSheet->Create(NULL, WS_THICKFRAME |WS_SYSMENU | WS_POPUP | WS_CAPTION | DS_MODALFRAME | WS_VISIBLE|WS_MINIMIZEBOX);
}

//Called when program is exiting.
void CChooseDB::DoneChoose()
{
	if (pBioSheet)
	{
		pBioSheet->DestroyWindow ();
		delete pBioSheet;
		pBioSheet = NULL;
	}
	if (pSWGSheet)
	{
		pSWGSheet->DestroyWindow ();
		delete pSWGSheet;
		pSWGSheet = NULL;
	}
	if (pCompSheet)
	{
		pCompSheet->DestroyWindow ();
		delete pCompSheet;
		pCompSheet = NULL;
	}
	if (pVehSheet)
	{
		pVehSheet->DestroyWindow ();
		delete pVehSheet;
		pVehSheet = NULL;
	}

	OnOK();
}
