// -----------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: ComponentPropertySheet.cpp
//
// Author: Dan Robbins
//
// Date Created: October 1998
//
// Description:  CComponentPropertySheet is the container for all
//               the Comp...Pages.  The member functions here
//               process menu selections.
//
//  Date		Who			Description
//	2000    Y. Wong Adding business rules, recode all edit boxs
//					and correct other errors.
// -----------------------------------------


#include "stdafx.h"
#include "entreev5.h"
#include "entreev5dlg.h"
#include "ComponentPropertySheet.h"

#include <winspool.h>

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CComponentPropertySheet

IMPLEMENT_DYNAMIC(CComponentPropertySheet, CPropertySheet)

CComponentPropertySheet::CComponentPropertySheet(UINT nIDCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(nIDCaption, pParentWnd, iSelectPage),
	_bClearAll( false )
{
	m_CompTestPage.m_pCompData	= &m_CompData;  // the data is available inside Test info dlg
	m_CompVehPage.m_pCompData	= &m_CompData;   // the data is available inside Vehicle info dlg
	m_CompInstPage.m_pCompData	= &m_CompData;  // the data is available inside Inst info dlg
	m_CompCompPage.m_pCompData	= &m_CompData;
	m_CompConfPage.m_pCompData	= &m_CompData;
	m_HsvdPage.m_pComHsvdData	= &m_CompData;
	m_HsvdPage.m_cVersion		= 'C';

	AddPage(&m_CompTestPage);
	AddPage(&m_CompCompPage);
	AddPage(&m_CompConfPage);
	AddPage(&m_CompInstPage);
	AddPage(&m_CompVehPage);
	AddPage(&m_HsvdPage);
	
	m_pParent = (CChooseDB *) pParentWnd;

	m_bValidate = false;
}

CComponentPropertySheet::CComponentPropertySheet(LPCTSTR pszCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(pszCaption, pParentWnd, iSelectPage),
	_bClearAll( false )
{
	m_CompTestPage.m_pCompData	= &m_CompData;  // the data is available inside Test info dlg
	m_CompVehPage.m_pCompData	= &m_CompData;   // the data is available inside Vehicle info dlg
	m_CompInstPage.m_pCompData	= &m_CompData;  // the data is available inside Inst info dlg
	m_CompCompPage.m_pCompData	= &m_CompData;
	m_CompConfPage.m_pCompData	= &m_CompData;
	m_HsvdPage.m_pComHsvdData	= &m_CompData;
	m_HsvdPage.m_cVersion = 'C';

	AddPage(&m_CompTestPage);
	AddPage(&m_CompCompPage);
	AddPage(&m_CompConfPage);
	AddPage(&m_CompInstPage);
	AddPage(&m_CompVehPage);
	AddPage(&m_HsvdPage);
	
	m_pParent = (CChooseDB *) pParentWnd;
	
}

CComponentPropertySheet::~CComponentPropertySheet()
{
}


BEGIN_MESSAGE_MAP(CComponentPropertySheet, CPropertySheet)
	//{{AFX_MSG_MAP(CComponentPropertySheet)
	ON_COMMAND(ID_BIOMECHDB, OnBiomechdb)
	ON_COMMAND(ID_SWGDB, OnSwgdb)
	ON_COMMAND(ID_VEHICLEDB, OnVehicledb)
	ON_COMMAND(ID_CLEARALL, OnClearall)
	ON_COMMAND(ID_EXPORT_TEST, OnExportTest)
	ON_COMMAND(ID_IMPORT_TEST, OnImportTest)
	ON_COMMAND(ID_FILE_LOAD_HSVD, OnImportHsvdData)
	ON_COMMAND(ID_FILE_SAVE_HSVD, OnExportHsvdData)
	ON_COMMAND(ID_FILE_SAVE_HSVD_REPORT, OnExportHsvdReport)
	ON_COMMAND(ID_FILE_PRINT, OnFilePrint)
	ON_COMMAND(ID_EXIT, OnExit)
	ON_COMMAND(ID_EXPORT_REPORT, OnExportReport)
	ON_WM_CLOSE()
	ON_COMMAND(ID_HELP_ABOUT, OnHelpAbout)
	ON_COMMAND(ID_HELP_INDEX, OnHelpIndex)
	ON_WM_INITMENUPOPUP()
	ON_WM_SYSCOMMAND()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CComponentPropertySheet message handlers

BOOL CComponentPropertySheet::OnInitDialog() 
{
	BOOL bResult = CPropertySheet::OnInitDialog();
	
	// modify propertysheet appearance.
	//Load Menu
	CMenu MyMenu;
	CMenu* pMenu=&MyMenu;
	pMenu->LoadMenu(IDR_PROPSHEET_MENU);
	// resize, buttons get cut off if you dont, because of menu.
    CRect rect;
	GetWindowRect(&rect);
    
	SetMenu(pMenu);

    MyMenu.CheckMenuItem (ID_COMPONENTDB, MF_CHECKED);
	MyMenu.Detach ();  // MyMenu wont be deleted after this function.

	SetWindowPos(&wndTop, rect.left,rect.top, rect.Width() +15, rect.Height()+20, SWP_NOZORDER);

	HICON hICN = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
	SetIcon(hICN,FALSE);

	CenterWindow();
	return bResult;
}

void CComponentPropertySheet::OnBiomechdb() 
{
	if (MessageBox("Exit Component Data Screens?",NULL,MB_YESNO)==IDYES)
	{
		CPropertySheet::OnClose();
		m_pParent->OnBiomechButton ();	
	}
	
}

void CComponentPropertySheet::OnSwgdb() 
{
	if (MessageBox("Exit Component Data Screens?",NULL,MB_YESNO)==IDYES)
	{
		CPropertySheet::OnClose();
		m_pParent->OnSwgButton ();	

	}
	
}

void CComponentPropertySheet::OnVehicledb() 
{
	if (MessageBox("Exit Component Data Screens?",NULL,MB_YESNO)==IDYES)
	{
		CPropertySheet::OnClose();
		m_pParent->OnVehicleButton ();	

	}
	
}


// This function is long.  Clear all edit boxes.  Clear all data from all
// arrays in m_CompData.  Then, reinitialize both with defaults.
void CComponentPropertySheet::OnClearall( void ) 
{
	if( AfxMessageBox( "Really clear all entries?", MB_YESNO ) == IDNO )
	{
		this->_bClearAll = false;
		return;	//	was returning FALSE;
	}
	
	//Clear all CompData ********************************
	m_CompData.m_title	="";
	m_CompData.m_tstobj	="";
	m_CompData.m_tstdat	="";
	m_CompData.m_tstprf	="";
	m_CompData.m_conno	="";
	m_CompData.m_tstref	="";
	m_CompData.m_tsttyp	="";
	m_CompData.m_temp	="";
	m_CompData.m_totcrv	=0;
	m_CompData.m_tstcom="";
	m_CompData.m_vehno	=0; 
	m_CompData.m_make.RemoveAll ();
	m_CompData.m_model.RemoveAll ();
	m_CompData.m_year.RemoveAll ();
	m_CompData.m_nhtsano.RemoveAll ();
	m_CompData.m_body.RemoveAll ();
	m_CompData.m_vin.RemoveAll ();
	m_CompData.m_crtest.RemoveAll ();
	m_CompData.m_vehcom.RemoveAll ();
	m_CompData.m_compsets = 0;
	m_CompData.m_Comp_vehno.RemoveAll ();
	m_CompData.m_cmpno.RemoveAll ();
	m_CompData.m_cmpnt.RemoveAll ();
	m_CompData.m_cmptyp.RemoveAll ();
	m_CompData.m_cmpwgt.RemoveAll ();
	m_CompData.m_modind.RemoveAll ();
	m_CompData.m_moddsc.RemoveAll ();
	m_CompData.m_occtyp.RemoveAll ();
	m_CompData.m_dumsiz.RemoveAll ();
	m_CompData.m_dumman.RemoveAll ();
	m_CompData.m_cmpcom.RemoveAll ();
	m_CompData.m_confsets = 0;
	m_CompData.m_Conf_vehno.RemoveAll ();
	m_CompData.m_Conf_cmpno.RemoveAll ();
	m_CompData.m_cnfno.RemoveAll ();
	m_CompData.m_tstdev.RemoveAll ();
	m_CompData.m_devspd.RemoveAll ();
	m_CompData.m_devcom.RemoveAll ();
	m_CompData.m_config.RemoveAll ();
	m_CompData.m_cmpspd.RemoveAll ();
	m_CompData.m_cntang.RemoveAll ();
	m_CompData.m_cntloc1.RemoveAll ();
	m_CompData.m_cntloc2.RemoveAll ();
	m_CompData.m_cntcom.RemoveAll ();
	m_CompData.m_cnfcom.RemoveAll ();
	m_CompData.m_Inst_vehno.RemoveAll ();
	m_CompData.m_Inst_cmpno.RemoveAll ();
	m_CompData.m_Inst_cnfno.RemoveAll ();
	m_CompData.m_curno = 0;
	m_CompData.m_sentyp.RemoveAll ();
	m_CompData.m_senloc.RemoveAll ();
	m_CompData.m_senatt.RemoveAll ();
	m_CompData.m_axis.RemoveAll ();
	m_CompData.m_xunits.RemoveAll ();
	m_CompData.m_yunits.RemoveAll ();
	m_CompData.m_prefil.RemoveAll ();
	m_CompData.m_insman.RemoveAll ();
	m_CompData.m_caldat.RemoveAll ();
	m_CompData.m_insrat.RemoveAll ();
	m_CompData.m_chlmax.RemoveAll ();
	m_CompData.m_inivel.RemoveAll ();
	m_CompData.m_nfp.RemoveAll ();
	m_CompData.m_nlp.RemoveAll ();
	m_CompData.m_delt.RemoveAll ();
	m_CompData.m_dastat.RemoveAll ();
	m_CompData.m_chstat.RemoveAll ();
	m_CompData.m_inscom.RemoveAll ();
	//Reinitialize CompData Arrays *******************
	m_CompData.m_make.SetAtGrow(0,""); m_CompData.m_make.SetAtGrow(1,""); m_CompData.m_make.SetAtGrow(2,"");
	m_CompData.m_model.SetAtGrow (0,""); m_CompData.m_model.SetAtGrow (1,""); m_CompData.m_model.SetAtGrow (2,"");
	m_CompData.m_year.SetAtGrow (0,"2000"); m_CompData.m_year.SetAtGrow (1,"2000"); m_CompData.m_year.SetAtGrow (2,"2000");
	m_CompData.m_nhtsano.SetAtGrow (0,"");m_CompData.m_nhtsano.SetAtGrow (1,"");m_CompData.m_nhtsano.SetAtGrow (2,"");
	m_CompData.m_body.SetAtGrow (0,"");m_CompData.m_body.SetAtGrow (1,"");m_CompData.m_body.SetAtGrow (2,"");
	m_CompData.m_vin.SetAtGrow (0,"");m_CompData.m_vin.SetAtGrow (1,"");m_CompData.m_vin.SetAtGrow (2,"");
	m_CompData.m_crtest.SetAtGrow (0,"");m_CompData.m_crtest.SetAtGrow (1,""); m_CompData.m_crtest.SetAtGrow (2,"");
	m_CompData.m_vehcom.SetAtGrow (0,"");m_CompData.m_vehcom.SetAtGrow (1,"");m_CompData.m_vehcom.SetAtGrow (2,"");
	m_CompData.m_Comp_vehno.SetAtGrow (0,""); m_CompData.m_Comp_vehno.SetAtGrow (1,"");
	m_CompData.m_cmpno.SetAtGrow (0,""); m_CompData.m_cmpno.SetAtGrow (1,"");
	m_CompData.m_cmpnt.SetAtGrow (0,"");m_CompData.m_cmpnt.SetAtGrow (1,"");
	m_CompData.m_cmptyp.SetAtGrow (0,"");m_CompData.m_cmptyp.SetAtGrow (1,"");
	m_CompData.m_cmpwgt.SetAtGrow (0,"");m_CompData.m_cmpwgt.SetAtGrow (1,"");
	m_CompData.m_modind.SetAtGrow (0,"");m_CompData.m_modind.SetAtGrow (1,"");
	m_CompData.m_moddsc.SetAtGrow (0,"");m_CompData.m_moddsc.SetAtGrow (1,"");
	m_CompData.m_occtyp.SetAtGrow (0,"");m_CompData.m_occtyp.SetAtGrow (1,"");
	m_CompData.m_dumsiz.SetAtGrow (0,"");m_CompData.m_dumsiz.SetAtGrow (1,"");
	m_CompData.m_dumman.SetAtGrow (0,"");m_CompData.m_dumman.SetAtGrow (1,"");
	m_CompData.m_cmpcom.SetAtGrow (0,"");m_CompData.m_cmpcom.SetAtGrow (1,"");
	m_CompData.m_Conf_vehno.SetAtGrow (0,""); m_CompData.m_Conf_vehno.SetAtGrow (1,"");
	m_CompData.m_Conf_cmpno.SetAtGrow (0,""); m_CompData.m_Conf_cmpno.SetAtGrow (1,"");
	m_CompData.m_cnfno.SetAtGrow (0,"");m_CompData.m_cnfno.SetAtGrow (1,"");
	m_CompData.m_tstdev.SetAtGrow (0,"");m_CompData.m_tstdev.SetAtGrow (1,"");
	m_CompData.m_devspd.SetAtGrow (0,"");m_CompData.m_devspd.SetAtGrow (1,"");
	m_CompData.m_devcom.SetAtGrow (0,"");m_CompData.m_devcom.SetAtGrow (1,"");
	m_CompData.m_config.SetAtGrow (0,"");m_CompData.m_config.SetAtGrow (1,"");
	m_CompData.m_cmpspd.SetAtGrow (0,"");m_CompData.m_cmpspd.SetAtGrow (1,"");
	m_CompData.m_cntang.SetAtGrow (0,"");m_CompData.m_cntang.SetAtGrow (1,"");
	m_CompData.m_cntloc1.SetAtGrow (0,"");m_CompData.m_cntloc1.SetAtGrow (1,"");
	m_CompData.m_cntloc2.SetAtGrow (0,"");m_CompData.m_cntloc2.SetAtGrow (1,"");
	m_CompData.m_cntcom.SetAtGrow (0,"");m_CompData.m_cntcom.SetAtGrow (1,"");
	m_CompData.m_cnfcom.SetAtGrow (0,"");m_CompData.m_cnfcom.SetAtGrow (1,"");
	m_CompData.m_Inst_vehno.SetAtGrow (0,"");m_CompData.m_Inst_vehno.SetAtGrow (1,"");
	m_CompData.m_Inst_cmpno.SetAtGrow (0,"");m_CompData.m_Inst_cmpno.SetAtGrow (1,"");
	m_CompData.m_Inst_cnfno.SetAtGrow (0,"");m_CompData.m_Inst_cnfno.SetAtGrow (1,"");
	m_CompData.m_sentyp.SetAtGrow (0,"");m_CompData.m_sentyp.SetAtGrow (1,"");
	m_CompData.m_senloc.SetAtGrow (0,"");m_CompData.m_senloc.SetAtGrow (1,"");
	m_CompData.m_senatt.SetAtGrow (0,"");m_CompData.m_senatt.SetAtGrow (1,"");
	m_CompData.m_axis.SetAtGrow (0,"");m_CompData.m_axis.SetAtGrow (1,"");
	m_CompData.m_xunits.SetAtGrow (0,"SEC");m_CompData.m_xunits.SetAtGrow (1,"SEC");
	m_CompData.m_yunits.SetAtGrow (0,"");m_CompData.m_yunits.SetAtGrow (1,"");
	m_CompData.m_prefil.SetAtGrow (0,"");m_CompData.m_prefil.SetAtGrow (1,"");
	m_CompData.m_insman.SetAtGrow (0,"");m_CompData.m_insman.SetAtGrow (1,"");
	m_CompData.m_caldat.SetAtGrow (0,"");m_CompData.m_caldat.SetAtGrow (1,"");
	m_CompData.m_insrat.SetAtGrow (0,"");m_CompData.m_insrat.SetAtGrow (1,"");
	m_CompData.m_chlmax.SetAtGrow (0,"");m_CompData.m_chlmax.SetAtGrow (1,"");
	m_CompData.m_inivel.SetAtGrow (0,"");m_CompData.m_inivel.SetAtGrow (1,"");
	m_CompData.m_nfp.SetAtGrow (0,"");m_CompData.m_nfp.SetAtGrow (1,"");
	m_CompData.m_nlp.SetAtGrow (0,"");m_CompData.m_nlp.SetAtGrow (1,"");
	m_CompData.m_delt.SetAtGrow (0,"");m_CompData.m_delt.SetAtGrow (1,"");
	m_CompData.m_dastat.SetAtGrow (0,"");m_CompData.m_dastat.SetAtGrow (1,"");
	m_CompData.m_chstat.SetAtGrow (0,"");m_CompData.m_chstat.SetAtGrow (1,"");
	m_CompData.m_inscom.SetAtGrow (0,"");m_CompData.m_inscom.SetAtGrow (1,"");

	// TestPage   ***********************
	m_CompTestPage.m_editconno	= _T("");
	m_CompTestPage.m_edittemp	= _T("");;
	m_CompTestPage.m_edittitle	= _T("");
	m_CompTestPage.m_edittotcrv = _T("0");
	m_CompTestPage.m_edittstcom = _T("");
	m_CompTestPage.m_edittstobj = _T("");
	m_CompTestPage.m_edittstprf = _T("");
	m_CompTestPage.m_edittstref = _T("");
	m_CompTestPage.m_edittsttyp = _T("");
	m_CompTestPage.m_editverno	= _T("C5");

	// VehPage    ***********************
	m_CompVehPage.m_editbody	= _T("");
	m_CompVehPage.m_editcrtest	= _T("");
	m_CompVehPage.m_editmake	= _T("");
	m_CompVehPage.m_editmodel	= _T("");
	m_CompVehPage.m_editnhtsano = _T("");
	m_CompVehPage.m_editvehcom	= _T("");
	m_CompVehPage.m_editvehno	= _T("1");
	m_CompVehPage.m_editvin		= _T("");
	m_CompVehPage.m_edityear		= _T("2000");

	// InstPage   ***********************

	m_CompInstPage.m_editaxis	= _T("");
	m_CompInstPage.m_editchlmax = _T("");
	m_CompInstPage.m_editchstat = _T("");
	m_CompInstPage.m_editcmpno	= _T("");
	m_CompInstPage.m_editcnfno	= _T("");
	m_CompInstPage.m_editcurno	= _T("0");
	m_CompInstPage.m_editdastat = _T("");
	m_CompInstPage.m_editdelt	= _T("");
	m_CompInstPage.m_editinivel = _T("");
	m_CompInstPage.m_editinscom = _T("");
	m_CompInstPage.m_editinsman = _T("");
	m_CompInstPage.m_editinsrat = _T("");
	m_CompInstPage.m_editnfp	= _T("");
	m_CompInstPage.m_editnlp	= _T("");
	m_CompInstPage.m_editprefil = _T("");
	m_CompInstPage.m_editsenatt = _T("");
	m_CompInstPage.m_editsentyp = _T("");
	m_CompInstPage.m_editxunits = _T("SEC");
	m_CompInstPage.m_edityunits = _T("");
	m_CompInstPage.m_totalcurves = 0;
	m_CompInstPage.m_icurno = 0;

	// CompPage   ***********************
	m_CompCompPage.m_editcmpcom = _T("");
	m_CompCompPage.m_editcmpno	= _T("");
	m_CompCompPage.m_editcmpnt	= _T("");
	m_CompCompPage.m_editcmptyp = _T("");
	m_CompCompPage.m_editcmpwgt = _T("");
	m_CompCompPage.m_editdumman = _T("");
	m_CompCompPage.m_editdumsiz = _T("");
	m_CompCompPage.m_editmoddsc = _T("");
	m_CompCompPage.m_editmodind = _T("");
	m_CompCompPage.m_editocctyp = _T("");
	m_CompCompPage.m_editvehno	= _T("");
	m_CompCompPage.m_curset = 0;
	m_CompCompPage.m_settot = 0;

	// ConfPage   ***********************
	m_CompConfPage.m_editcfncom = _T("");
	m_CompConfPage.m_editcmpno	= _T("");
	m_CompConfPage.m_editcmpspd = _T("");
	m_CompConfPage.m_editcnfno	= _T("");
	m_CompConfPage.m_editcntang = _T("");
	m_CompConfPage.m_editcntcom = _T("");
	m_CompConfPage.m_editcntloc1 = _T("");
	m_CompConfPage.m_editcntloc2 = _T("");
	m_CompConfPage.m_editconfig = _T("");
	m_CompConfPage.m_editdevcom = _T("");
	m_CompConfPage.m_editdevspd = _T("");
	m_CompConfPage.m_edittstdev = _T("");
	m_CompConfPage.m_editvehno	= _T("");
	m_CompConfPage.m_curset = 0;
	m_CompConfPage.m_settot = 0;
	
	if (m_CompConfPage.m_hWnd)
	{
		m_CompConfPage.m_conflist.ResetContent ();
		m_CompConfPage.UpdateData(FALSE);
	}

	if (m_CompTestPage.m_hWnd!=NULL) m_CompTestPage.UpdateData(FALSE);
	
	if (m_CompInstPage.m_hWnd!=NULL) 
	{
		m_CompInstPage.m_curvelist.ResetContent();
		m_CompInstPage.UpdateData(FALSE);
		
	}
	
	if (m_CompVehPage.m_hWnd!=NULL) m_CompVehPage.UpdateData (FALSE);
	
	if (m_CompCompPage.m_hWnd!=NULL) 
	{
		m_CompCompPage.m_complist.ResetContent ();
		m_CompCompPage.UpdateData(FALSE);
	
	}
	
	m_CompData.ClearHsvddata();
	if (m_HsvdPage.m_hWnd!=NULL) { m_HsvdPage.ClearAll(); }	// for high speed video

	this->_bClearAll = true;
	return;	// was returning TRUE;
	
}

// Load data from all pages into CompData.  If success,
// let the user export an EV5 file containing this data.
void CComponentPropertySheet::OnExportTest() 
{
	// Get latest data from pages - if already loaded, no big deal.
	if (!m_CompTestPage.LoadCompTestData ()) return;
	if (!m_CompVehPage.LoadCompVehData ()) return;
	if (!m_CompCompPage.LoadCompCompData ()) return;
	if (!m_CompConfPage.LoadCompConfData ()) return;
	if (!m_CompInstPage.LoadCompInstData ()) return;

	//Warn about no Configurations or Components.
	if ((m_CompData.m_compsets ==0) && (m_CompData.m_confsets==0))
	{
		MessageBox("This test has no configuration or component records.","Warning");
	}

	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Export File";
	export.m_ofn.lpstrFilter = "EV5 File (*.ev5)\0*.ev5\0";

	if (export.DoModal()==IDOK)
	{
		//export here
		CString strfile_out = export.GetPathName ();
		if (export.GetFileExt ()!="ev5")
		{
			strfile_out +=".ev5";
		}
		m_CompData.ExportEV5 (strfile_out);

		// export high-speed video data
		if( m_CompData.m_camno.GetSize()<2 ) { return; }

		if ( !m_HsvdPage.ValidateThisPage() ) 
		{ 
			AfxMessageBox("Illegal data found. No file output.");
			return; 
		}

		strfile_out.TrimRight();
		CString HsvdFile = strfile_out.Left(strfile_out.GetLength()-4) + ".hs5";
		m_CompData.ExportHsvd( HsvdFile );
	}
	
}	// OnExportTest

// Let the user choose a file to import, and then try to load it.
void CComponentPropertySheet::OnImportTest() 
{
	CFileDialog import(TRUE);
	import.m_ofn.lpstrTitle ="Open Test";
	import.m_ofn.lpstrFilter =
	 "EV5 Tests (*.ev5)\0*.ev5\0EV4 Tests (*.ev4)\0*.ev4\0EV3 Test Data (*.gr1)\0*.gr1\0EV3 Instrumentation Data (*.gr5)\0*.gr5\0EV3 Component Data (*.gr9)\0*.gr9\0";

	if (import.DoModal ()==IDOK)
	{
		//import here
		CString strfile_in = import.GetPathName () ;
		CString strext = import.GetFileExt ();
		strext.MakeLower ();  //lower case comparisons.

		if (strext == "ev5") 
		{
			OnClearall();
			if( this->_bClearAll == false )
			{
				//	exit if user doesn't want to 
				//	replace current data with imported data.
				return;
			}
			
			BOOL success = m_CompData.ImportEV5(strfile_in);
			if (success) 
			{
				m_CompTestPage.OnSetActive ();  //m_hWnd always exists

				m_CompCompPage.m_curset = m_CompData.m_compsets;	
				if (m_CompCompPage.m_hWnd)	{ m_CompCompPage.OnSetActive(); }

				m_CompConfPage.m_curset = m_CompData.m_confsets;
				if (m_CompConfPage.m_hWnd)  { m_CompConfPage.OnSetActive(); }
				
				m_CompInstPage.m_icurno = m_CompData.m_totcrv;
				if (m_CompInstPage.m_hWnd)	{ m_CompInstPage.OnSetActive(); }

				if (m_CompVehPage.m_hWnd)	{ m_CompVehPage.OnSetActive(); }
				
			}

			// import High Speed Video data
			strfile_in.TrimRight();
			CString HsvdFile = strfile_in.Left(strfile_in.GetLength()-4) + ".hs5";
			ImportHsvdData(HsvdFile, false);
		}
		else if (strext=="ev4")
		{
			OnClearall();
			if( this->_bClearAll == false )
			{
				//	exit if user doesn't want to 
				//	replace current data with imported data.
				return;
			}
			
			BOOL success = m_CompData.ImportEV4(strfile_in);
			if (success) 
			{
				m_CompTestPage.OnSetActive ();  //m_hWnd always exists

				m_CompCompPage.m_curset = m_CompData.m_compsets; 	
				if (m_CompCompPage.m_hWnd) { m_CompCompPage.OnSetActive(); }

				m_CompConfPage.m_curset = m_CompData.m_confsets;
				if (m_CompConfPage.m_hWnd) { m_CompConfPage.OnSetActive(); }
				
				m_CompInstPage.m_icurno = m_CompData.m_totcrv; 
				if (m_CompInstPage.m_hWnd) { m_CompInstPage.OnSetActive(); }

				if (m_CompVehPage.m_hWnd) m_CompVehPage.OnSetActive();
				
			}
			
		}
		else if (strext=="gr1")
		{
			
			BOOL success= m_CompData.ImportGR1(strfile_in);
			if (success) 
			{
				m_CompTestPage.OnSetActive ();  //m_hWnd always exists
				if (m_CompCompPage.m_hWnd) { m_CompCompPage.OnSetActive(); }
				if (m_CompConfPage.m_hWnd) { m_CompConfPage.OnSetActive(); }
				if (m_CompInstPage.m_hWnd) { m_CompInstPage.OnSetActive(); }
				if (m_CompVehPage.m_hWnd)  { m_CompVehPage.OnSetActive(); }
			}
			
		}
		else if (strext=="gr5")
		{
			
			BOOL success= m_CompData.ImportGR5(strfile_in);
			if (success) 
			{
				m_CompTestPage.OnSetActive ();  //m_hWnd always exists
				m_CompInstPage.m_icurno = m_CompData.m_totcrv;  //goto last curve.

				if (m_CompCompPage.m_hWnd) { m_CompCompPage.OnSetActive(); }
				if (m_CompConfPage.m_hWnd) { m_CompConfPage.OnSetActive(); }
				if (m_CompInstPage.m_hWnd) { m_CompInstPage.OnSetActive(); }
				if (m_CompVehPage.m_hWnd)  { m_CompVehPage.OnSetActive(); }
			}
			
		}
		else if (strext=="gr9")
		{
			short nSets= m_CompData.ImportGR9(strfile_in);
			
			if (nSets) 
			{
				
				m_CompData.m_compsets = nSets;
				
				m_CompTestPage.OnSetActive ();  //m_hWnd always exists

				m_CompCompPage.m_curset = m_CompData.m_compsets;  //goto last curve.	
			
				if (m_CompCompPage.m_hWnd)	{ m_CompCompPage.OnSetActive(); }
				if (m_CompConfPage.m_hWnd)	{ m_CompConfPage.OnSetActive(); }
				if (m_CompInstPage.m_hWnd)	{ m_CompInstPage.OnSetActive(); }
				if (m_CompVehPage.m_hWnd)	{ m_CompVehPage.OnSetActive(); }
			}	
		}	
	}
}	// OnImportTest

void CComponentPropertySheet::OnExit() 
{
	
	OnClose();	
}




//  *************************
//  Ask user which file to print.  Then ask which printer to print with.
//  Then do an annoying line by line print loop.  There must be a better 
//  way to do this.  See ch15 from Programming Windows 95 by Petzold.
//  *************************
void CComponentPropertySheet::OnFilePrint() 
{

	CString strfile_out= GetPrintFileName();
	if (strfile_out=="") return;  // no file chosen, cancel.

	CString device = GetPrinterDeviceName();
	if (device == "") return; // no printer chosen, cancel.

	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_out, CFile::shareDenyNone | CFile::modeRead | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(msg);
		return ;
	}
	
	static DOCINFO di={sizeof(DOCINFO), strfile_out,NULL};

	HDC hdcPrn = CreateDC("WINSPOOL", device, NULL, NULL);

	// size of page and chars and lines per page.
	TEXTMETRIC tm;
	GetTextMetrics(hdcPrn, &tm);
	int yChar, nline = 0;
	yChar = tm.tmHeight +tm.tmExternalLeading;
	int iCharsPerLine = GetDeviceCaps(hdcPrn, HORZRES) /tm.tmAveCharWidth ;
	int iLinesPerPage = GetDeviceCaps(hdcPrn, VERTRES) / yChar;
	
	StartDoc (hdcPrn, &di);
	StartPage (hdcPrn);
	
	CString strbuf;
	char* pBuf = new char[iCharsPerLine + 1];
	// readstrings from file.  
	while (myFile.ReadString(pBuf, iCharsPerLine)) //reads max of iCharsPerLine chars.
	{
		if (nline == iLinesPerPage)  //new page
		{
			nline = 0;
			EndPage(hdcPrn);
			StartPage(hdcPrn);
		}
		// WARNING! TextOut doesn't handle Tabs well, so there are no tabs in .ev5 or .evr.
		strbuf = pBuf;
		TextOut(hdcPrn,0,yChar*nline, strbuf, strbuf.GetLength ());
		nline++;
		
	}

	EndPage(hdcPrn);
	EndDoc(hdcPrn);
	DeleteDC(hdcPrn);
	delete [] pBuf;
	myFile.Close ();
	return;

}

CString CComponentPropertySheet::GetPrintFileName()
{
	// Get Print File Name  **********
	CFileDialog printfile(TRUE);
	CString strfile_out;
	printfile.m_ofn.lpstrTitle ="Choose File To Print";
	printfile.m_ofn.lpstrFilter = "EV5 File (*.ev5)\0*.ev5\0EV5 Report File (*.evr)\0*.evr\0";

	if (printfile.DoModal()==IDOK)
	{
		strfile_out = printfile.GetPathName ();
	}
	else
	{
		strfile_out = "";
	}
	return strfile_out;

}

CString CComponentPropertySheet::GetPrinterDeviceName()
{
	CString device;
	// Choose Printer to use ************
	CPrintDialog printmachine(FALSE);
	
	if (printmachine.DoModal ()==IDOK)
	{
		device = printmachine.GetDeviceName();
		GlobalFree(printmachine.m_pd.hDevMode );
		GlobalFree(printmachine.m_pd.hDevNames );
	}
	else
	{
		GlobalFree(printmachine.m_pd.hDevMode );
		GlobalFree(printmachine.m_pd.hDevNames );
		device = "";
	}
	return device;

}

// Try to load all data into m_CompData.  If success,
// let the user export this data into a report (EVR) file.
void CComponentPropertySheet::OnExportReport() 
{
	// Get latest data from pages - if already loaded, no big deal.
	if (!m_CompTestPage.LoadCompTestData ()) return;
	if (!m_CompCompPage.LoadCompCompData ()) return;
	if (!m_CompConfPage.LoadCompConfData ()) return;
	if (!m_CompVehPage.LoadCompVehData ()) return;
	if (!m_CompInstPage.LoadCompInstData ()) return;

	// File export dialog common control
	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Export Report";
	export.m_ofn.lpstrFilter = "EV5 Report (*.evr)\0*.evr\0";

	if (export.DoModal()==IDOK)
	{
		//export here
//		CString strfile_out = export.GetPathName () + ".evr";
//		m_CompData.ExportEVR (strfile_out);
		CString strfile_out = export.GetPathName ();
		if (export.GetFileExt ()!="evr")
		{
			strfile_out +=".evr";
		}
		m_CompData.ExportEVR (strfile_out);

		// Export high speed video report
		if( m_CompData.m_camno.GetSize()<2 ) { return; }

		if ( !m_HsvdPage.ValidateThisPage() ) 
		{ 
			AfxMessageBox("Illegal data found. No file output.");
			return; 
		}

		strfile_out.TrimRight();
		CString HsvdFile = strfile_out.Left(strfile_out.GetLength()-4) + ".hsr";
		m_CompData.ExportHsvdReport( HsvdFile );
	}	
}	// OnExportReport

void CComponentPropertySheet::OnClose() 
{
	if (MessageBox("Really exit Entree?", "Warning", MB_YESNO)==IDYES)
	{
		m_pParent->DoneChoose();	
	}
}

void CComponentPropertySheet::OnHelpAbout() 
{
	CAboutDlg about;
	about.DoModal ();
}

void CComponentPropertySheet::OnHelpIndex() 
{
	OnHelpFinder();	
}

void CComponentPropertySheet::OnInitMenuPopup(CMenu* pPopupMenu, UINT nIndex, BOOL bSysMenu) 
{
	CPropertySheet::OnInitMenuPopup(pPopupMenu, nIndex, bSysMenu);
	
	if( nIndex != 0 )
	{
		return;
	}

	if( m_bValidate == true )
	{
		pPopupMenu->EnableMenuItem( ID_EXPORT_TEST, MF_ENABLED );		
	}
	else
	{
		pPopupMenu->EnableMenuItem( ID_EXPORT_TEST, MF_GRAYED );
	}
	
	// for intrusion point
	pPopupMenu->EnableMenuItem( ID_FILE_LOAD_INTRUSION, MF_GRAYED );
	pPopupMenu->EnableMenuItem( ID_FILE_SAVE_INTRUSION, MF_GRAYED );
	pPopupMenu->EnableMenuItem( ID_FILE_SAVE_INTRUSION_REPORT, MF_GRAYED );
}

void CComponentPropertySheet::OnSysCommand(UINT nID, LPARAM lParam) 
{

	LockWindowUpdate();

	int iActivePage = 0;
	iActivePage = GetActiveIndex();

	if(		( m_CompTestPage.ValidateTestPage() == true ) 
		&&	( m_CompCompPage.ValidateCompPage() == true )
		&&	( m_CompConfPage.ValidateConfPage() == true )
		&&	( m_CompVehPage.ValidateVehPage() == true )
		&&	( m_CompInstPage.ValidateInstPage() == true ) )
	{
		m_bValidate = true;

		SetActivePage( 4 );

		if( m_CompVehPage.m_hWnd )
		{
			if( m_CompVehPage.ValidateSpinControl() == false )
			{
				m_bValidate = false;
			}
		}

		SetActivePage( iActivePage );
	}
	else
	{
		m_bValidate = false;
	}

	UnlockWindowUpdate();
	
	CPropertySheet::OnSysCommand(nID, lParam);
}

////////////// for high-speed video files only
void CComponentPropertySheet::OnImportHsvdData()
{
	CFileDialog import(TRUE);
	import.m_ofn.lpstrTitle ="Open High-Speed Video File";
	import.m_ofn.lpstrFilter = "EV5 HSVD (*.hs5)\0*.hs5\0";
//	 "EV5 Tests (*.ev5)\0*.ev5\0EV4 Tests (*.ev4)\0*.ev4\0EV3 Test Data (*.gr1)\0*.gr1\0EV3 Vehicle Data (*.gr2)\0*.gr2\0EV3 Barrier Data (*.gr3)\0*.gr3\0EV3 Occupant Data (*.gr4)\0*.gr4\0EV3 Instrumentation Data (*.gr5)\0*.gr5\0";
	 
	if (import.DoModal ()==IDCANCEL) { return; }
	CString strfile_in = import.GetPathName () ;
	ImportHsvdData(strfile_in);
}	// OnImportHsvdData

void CComponentPropertySheet::OnExportHsvdData()
{
	ExportHsvdData();
}	// OnExportHsvdData

void CComponentPropertySheet::ImportHsvdData(CString& strfile_in, bool bErrMsgResponse) // = true
{
	if( !m_CompData.ImportHsvd(strfile_in, bErrMsgResponse) ) { return; }
	m_HsvdPage.m_nCurCamNo = m_HsvdPage.m_nTotalCamNo = m_CompData.m_camno.GetSize() - 1;	// the 0th item is empty.
	m_CompTestPage.OnSetActive ();  //m_hWnd always exists
	if (m_HsvdPage.m_hWnd) m_HsvdPage.OnSetActive();

}	// ImportHsvdData

void CComponentPropertySheet::ExportHsvdData()
{
	if( m_CompData.m_camno.GetSize()<2 ) { return; }
//	m_HsvdPage.LoadHsvdData();
	
	if ( !m_HsvdPage.ValidateThisPage() ) 
	{ 
		AfxMessageBox("Illegal data found. No file output.");
		return; 
	}

	//File Export Dialog Common Control
	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Export File";
	export.m_ofn.lpstrFilter = "EV5 HSVD (*.hs5)\0*.hs5\0";

	if( export.DoModal() == IDCANCEL ) { return; }
	
	//export here
	CString strfile_out = export.GetPathName();
	if( export.GetFileExt() != "hs5" )
	{
		strfile_out += ".hs5";
	}

	m_CompData.ExportHsvd( strfile_out );

}	// ExportHsvdData

void CComponentPropertySheet::OnExportHsvdReport()
{
	ExportHsvdReport();
}	// OnExportHsvdReport


void CComponentPropertySheet::ExportHsvdReport()
{
	if( m_CompData.m_camno.GetSize()==0 ) { return; }
		
	if ( !m_HsvdPage.ValidateThisPage() ) 
	{ 
		AfxMessageBox("Illegal data found. No file output.");
		return; 
	}

	//File Export Dialog Common Control
	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Report File";
	export.m_ofn.lpstrFilter = "EV5 HSVD (*.hsr)\0*.hsr\0";

	if( export.DoModal() == IDCANCEL ) { return; }
	
	//export here
	CString strfile_out = export.GetPathName();
	if( export.GetFileExt() != "hsr" )
	{
		strfile_out += ".hsr";
	}

	m_CompData.ExportHsvdReport( strfile_out );

}	// ExportHsvdReport