// ----------------------------------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: ExecuteStoredProc.cpp
//
// Author: Yeun Wong
//
// Date Created: October, 2000
//
// Description:  Use ADO technique to execute stored procedures
//
// ----------------------------------------------------------------

#include <string>

#include "ExecuteStoredProc.h"

CAdoStoredProcExe::CAdoStoredProcExe()
{
	m_username = m_password = "";
	m_IsConnectionOpen	= false;
	m_UseAltConnection	= false;

	m_pConnection		= NULL;
	m_pCommand			= NULL;
	m_pRecordSet		= NULL;
}	// 

CAdoStoredProcExe::CAdoStoredProcExe(_ConnectionPtr pConnection)
{
	m_username = m_password = "";
	m_IsConnectionOpen	= false;
	m_UseAltConnection	= false;

	m_pConnection		= pConnection;
	m_pCommand			= NULL;
	m_pRecordSet		= NULL;
}	//

CAdoStoredProcExe::~CAdoStoredProcExe()
{
	if (m_pConnection->State == adStateOpen)	{ m_pConnection->Close(); m_pConnection	= NULL; }
	if (m_pCommand)		{ m_pCommand->Release(); m_pCommand = NULL; }
	if (m_pRecordSet)	{ m_pRecordSet->Close(); m_pRecordSet = NULL; }
}	// 

bool CAdoStoredProcExe::OpenDatabase(const CString sPathAndDbName)
{
	_bstr_t username = m_username;
	_bstr_t password = m_password;
	
	HRESULT hr;
	try
	{
		hr = m_pConnection.CreateInstance( __uuidof( Connection ) );
		if (SUCCEEDED(hr))
		{ //Open connection to DB
			CString strOpen("");
			strOpen = CString("Provider=Microsoft.Jet.OLEDB.4.0;") \
					+ CString("Data Source=") + sPathAndDbName + CString(";"); 
			hr = m_pConnection->Open( _bstr_t(strOpen), username, username, adOpenUnspecified );
			if (SUCCEEDED(hr)) { m_IsConnectionOpen = TRUE; }			
		}
	}
	catch (_com_error *e) //handle com errors
	{
		CString Error = e->ErrorMessage();
		AfxMessageBox(Error);
		return false;						
	}
	catch (...)  //handle all other errors.  See codeguru->Database->ADO is AOK, Dmitri's response.
	{
		ConnectionErrors();
		return false;
	}

	return true;
}	// OpenDatabase

// ----------------------------------------------------------------
// Executes a stored procedure with single parameter only
// collection (which is not used here)
// SPName = Stored procedute name
// ParamArray = SAFEARRAY of the parameters
// Returns IDispatch (in a VARIANT) of the Recordset.
// ----------------------------------------------------------------
STDMETHODIMP CAdoStoredProcExe::ADOExecuteSP(BSTR SPName, const CString single_param, _variant_t& Result)
{
	try
	{
		_CommandPtr pCommand; 
		pCommand.CreateInstance(__uuidof(Command));
		pCommand->ActiveConnection = m_pConnection;
		pCommand->CommandType = adCmdStoredProc; 
		pCommand->CommandText = _bstr_t( SPName );

		_bstr_t bsParameter = single_param;
		_variant_t vRecsAffected; vRecsAffected.vt = VT_INT;
		_variant_t vParameter = single_param;
//		if (single_param!="") { vParameter = single_param; }
//		else { vParameter.vt = VT_NULL; }	// ok?

		m_pConnection->CursorLocation = adUseClient;
		_RecordsetPtr pRecordSet = pCommand->Execute( &vRecsAffected, &vParameter, adCmdStoredProc);

		_variant_t Holder = static_cast<IDispatch*>(pRecordSet);
		Result = Holder.Detach();
	}
	catch(_com_error *e)
	{
		CString Error = e->ErrorMessage();
		AfxMessageBox(Error);
		return S_FALSE;
	}
	catch(...)
	{
		ConnectionErrors();
		return S_FALSE;
	}
	return S_OK;
}	// ADOExecuteSP

// ----------------------------------------------------------------
// Executes a stored procedure (no return values supprted without the use of the Parameter
// collection (which is not used here)
// SPName = Stored procedute name
// ParamArray = SAFEARRAY of the parameters
// Returns IDispatch (in a VARIANT) of the Recordset.
// ----------------------------------------------------------------
STDMETHODIMP CAdoStoredProcExe::ADOExecuteSP(BSTR SPName, VARIANT ParamArray, _variant_t& Result)
{
	VARIANT RecordsEffected; RecordsEffected.vt = VT_INT;
	_variant_t Holder;

	try
	{
		if(m_UseAltConnection)
		{	
			if(m_pRecordSet == NULL) m_pRecordSet.CreateInstance(__uuidof(Recordset));
			if(m_pRecordSet->State == adStateOpen) m_pRecordSet->Close();

			// Now set up the command object
			m_pCommand->ActiveConnection = m_pConnection;
			// enter the SP name
			m_pCommand->CommandText = _bstr_t(SPName);
			// Now execute it
			m_pRecordSet->CursorLocation = adUseClient;
			m_pRecordSet = m_pCommand->Execute(&RecordsEffected,&ParamArray,adCmdStoredProc);
			Holder = static_cast<IDispatch*>(m_pRecordSet);
			Result = Holder.Detach();
		}
		else
		{
			if(m_pRecordSet == NULL) m_pRecordSet.CreateInstance(__uuidof(Recordset));
			if(m_pRecordSet->State == adStateOpen) m_pRecordSet->Close();

			// Now set up the command object
			m_pCommand.CreateInstance(__uuidof(Command));
			m_pCommand->ActiveConnection = m_pConnection;
			// enter the SP name
			m_pCommand->CommandText = _bstr_t(SPName);
			// Now execute it
			m_pRecordSet->CursorLocation = adUseClient;
			m_pRecordSet = m_pCommand->Execute(&RecordsEffected,&ParamArray,adCmdStoredProc);

			Holder = static_cast<IDispatch*>(m_pRecordSet);
			Result = Holder.Detach();		
		}
	}
	catch(_com_error *e)
	{
		CString Error = e->ErrorMessage();
		AfxMessageBox(Error);
		return S_FALSE;
	}
	catch(...)
	{
		ConnectionErrors();
		return S_FALSE;
	}

	return S_OK;
}	// ADOExecuteSP

// ----------------------------------------------------------------
// Executes a stored procedure with any aprameters
// collection (which is not used here)
// SPName = Stored procedute name
// ParamArray = SAFEARRAY of the parameters
// Returns IDispatch (in a VARIANT) of the Recordset.
// ----------------------------------------------------------------
const _variant_t CAdoStoredProcExe::ADOExecuteSP(const CString SPName, CString sParamList)
{
	CString sParamType, sParamValue;
	int n = 0;
	_variant_t pRS;

	if (sParamList!="")
	{
		n = ParseParam(sParamList, sParamType, sParamValue);
	}
	
	if (n>1) 
	{
		SAFEARRAY* arrSafe;
		ADOMakeSafeArray(n, (_bstr_t) sParamType, (_bstr_t) sParamValue, &arrSafe);

		VARIANT vtSafeArr; 
		VariantInit(&vtSafeArr);
		vtSafeArr.vt = VT_VARIANT | VT_ARRAY; 
		vtSafeArr.parray = arrSafe;	
		
		ADOExecuteSP((_bstr_t) SPName, vtSafeArr, pRS );
	}
	else
	{
		ADOExecuteSP((_bstr_t) SPName, sParamList, pRS );
	}

	return (_variant_t) pRS;
}	// ADOExecuteSP

// ----------------------------------------------------------------
// Simple way to create a single dimension SAFEARRAY to be used with the 
// Stored Procedure methods.
// ArraySize = the number of eliments in the safearray
// Types = comma delimited list of data types (I suppoer L=long, D=double, S=VARCHAR)
// You can supply more if you like.
// Values = comma delimited list of the values.  All values in string format, no
// quotation marks needed
// Sample call:
// SAFEARRAY Holder;
// Holder = MyBK->ADOMakeSaveArray(3,"L,L,S","2,4,Atlanta");
// ----------------------------------------------------------------
STDMETHODIMP CAdoStoredProcExe::ADOMakeSafeArray(short ArraySize, BSTR Types, BSTR Values, SAFEARRAY **Result)
{
	if (ArraySize==0) { return !S_OK; }

	std::string AllTypes;
	std::string AllValues;
	std::string ThisType;
	std::string ThisValue;
	long CurrentPosition = 0;
	int ComaPosition = 0;

	AllTypes = (char*)_bstr_t(Types);
	AllValues = (char*)_bstr_t(Values);

	SAFEARRAYBOUND asBound[1];
	asBound->cElements = ArraySize;
	asBound->lLbound = 0;

	*Result = SafeArrayCreate(VT_VARIANT,1,asBound);

	while(CurrentPosition < ArraySize)
	{
		VARIANT Holder;
		ComaPosition = AllTypes.find(',',0);
		if(ComaPosition != -1)
			ThisType = AllTypes.substr(0,ComaPosition);
		else
			ThisType = AllTypes;
		if(ComaPosition != -1)
			AllTypes = AllTypes.substr(ComaPosition+1);
		else
			AllTypes = AllTypes;


		ComaPosition = AllValues.find(',',0);
		if(ComaPosition != -1)
			ThisValue = AllValues.substr(0,ComaPosition);
		else
			ThisValue = AllValues;
		if(ComaPosition != -1)
			AllValues = AllValues.substr(ComaPosition+1);
		else
			AllValues = AllValues;

		// now the correct values are in the type and value 
		if(ThisType.find('L')!=-1)
			Holder = _variant_t((long)atol(ThisValue.c_str())).Detach();
		if(ThisType.find('D')!=-1)
			Holder = _variant_t((double)atof(ThisValue.c_str())).Detach();
		if(ThisType.find('S')!=-1)
			Holder = _variant_t(ThisValue.c_str()).Detach();
		
		SafeArrayPutElement(*Result,&CurrentPosition,&Holder);
		CurrentPosition++;
	}
	return S_OK;
}	// ADOMakeSafeArray

void CAdoStoredProcExe::ConnectionErrors()
{
	ErrorPtr errItem;
	_variant_t vIndex;
	_bstr_t strstr;
	long iNum=0;

	m_pConnection -> Errors -> get_Count(&iNum);

	for(int i = 0; i < iNum; i++)
	{
		vIndex.vt = VT_I4;
		vIndex.lVal = i;
		errItem = m_pConnection -> Errors ->GetItem(vIndex);
		strstr = errItem -> Description;
		AfxMessageBox(strstr);
	}

}	// ConnectionErrors

const bool CAdoStoredProcExe::isInteger(const CString Str) 
{
	CString str = Str; str.TrimLeft(); str.TrimRight();
	if (str=="") { return false; }

	if ( ((str[0]<48)||(str[0]>57)) && (str[0]!='-') ) { return false; }
	for (int i=1; i<str.GetLength(); i++)
	{
		if ( (str[i]<48)||(str[i]>57) ) { return false; }
	}
	return true;

}	// isInteger

//----------------------------------------------------------------------
// isNumber()
// Description: is the string a number?
//----------------------------------------------------------------------
const bool CAdoStoredProcExe::isNumber(const CString Str)
{
	CString str = Str; str.TrimLeft(); str.TrimRight();
	int nLen = str.GetLength();
	if (nLen==0) { return false; }
	int dotIndex = 0;

	if ( ((str[0]<48)||(str[0]>57)) && (str[0]!='-') ) { return false; }
	for (int i=1; i<nLen; i++)
	{
		if (str[i]==46) 
		{
			if (dotIndex==0) { dotIndex++; }
			else return false;
		}
		else if (str[i]=='E' || str[i]=='e')	// scientific notation
		{
			if ( (str[++i]!='+') && (str[i]!='-') ) { return false; }
			for (int j=i+1; j<nLen; j++)
			{
				if ( (str[j]<48)||(str[j]>57) ) { return false; } // isdigit(str[j])
			}
			return true;
		}
		else if ( (str[i]<48)||(str[i]>57) ) { return false; }
	}

	return true;
}	// isNumber


//----------------------------------------------------------------------
// ParseParam()
// Description: Parsing parameters in CStringArray to determine
//				types and values of parameters
//----------------------------------------------------------------------
const int CAdoStoredProcExe::ParseParam( const CString sParamList, CString& sParamType, CString& sParamValue)
{
	int count = 0;
	CString paramList = sParamList; paramList.TrimLeft(); paramList.TrimRight();
	int n = paramList.GetLength();
	CString buf = "";
	for (int i=0; i<n; i++)
	{
		if (paramList[i]!=',') { buf += paramList[i]; }
		else
		{			
			buf.TrimLeft(); buf.TrimRight();
			sParamValue += buf + ",";
			if (isInteger(buf)) { sParamType += CString("L") + ",";  }
			else if (isNumber(buf)) { sParamType += CString("D") + ","; }
			else { sParamType += CString("S") + ","; }
			buf = "";
			count++;
		}
	}

	if (buf!="")
	{
			buf.TrimLeft(); buf.TrimRight();
			sParamValue += buf;
			if (isInteger(buf)) { sParamType += CString("L");  }
			else if (isNumber(buf)) { sParamType += CString("D"); }
			else { sParamType += CString("S"); }
			count++;
	}

	int tpLast = sParamType.GetLength()-1;
	if (tpLast<0) { return false; }
	if (sParamType.GetAt(tpLast)==',') { sParamType.Delete(tpLast); }
	int vlLast = sParamValue.GetLength()-1;
	if (vlLast<0) { return false; }
	if (sParamValue.GetAt(vlLast)==',') { sParamValue.Delete(vlLast); }

	return count;
}	// ParseParam