// ----------------------------------------------------------------------------------
// File: Search.cpp
//
// Description:  
//               Display a dlg with results of SQL Query 
//               so the user can select an item. 
//				 Use ADO technique to get inside the ado recordset.
//
// ReCoding: Yeun T Wong in 2000 ( ADO version )
// Update:	 Adding quick search and redesign the search box, 2003
// ----------------------------------------------------------------------------------

#include "stdafx.h"
#include "entreeV5.h"
#include "Search.h"

#include "ExecuteStoredProc.h"
#include ".\search.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

CString search_code="";

const NUM_LOGCOLUMNS = 4;	// the Search listbox has 4 columns of text
static unsigned char _gnLogColTypes[NUM_LOGCOLUMNS] = 
{
	LVEX_CASE, LVEX_CASE, LVEX_CASE, LVEX_CASE
};

/////////////////////////////////////////////////////////////////////////////
// CSearch dialog

CSearch::CSearch(CWnd* pParent /*=NULL*/, CString codename, CString db, CString sqlselect, bool bSenatt/*=false*/)
	: CDialog(CSearch::IDD, pParent)
{
	m_codename		= codename;
	m_db			= db;
	m_SQLSelect		= sqlselect;
	
	m_SqlCommand	=  true;
	m_bSenatt		= bSenatt;

	m_bDataFound	= true;
	m_sQCode		= "";
	m_sOldQCode		= "";

	m_sSecondCode	= "";
	m_sColName0		= "";
	m_sColName1		= "";
	m_sColName2		= "";
	m_sColName3		= "";

	Array0.RemoveAll();
	Array1.RemoveAll();
	Array2.RemoveAll();
	Array3.RemoveAll();
}

void CSearch::runStoredProc( CString storedproc, CString parameter, CString codename, CString db, CWnd* pParent )
{
	m_codename = codename;
	m_db = db;

	m_storedproc = storedproc;
	m_parameter = parameter;

	m_SqlCommand = false;

	StoredProcExecution();
}

void CSearch::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSearch)
	DDX_Control(pDX, IDC_CLEAR, m_clear);
	DDX_Control(pDX, IDC_SEARCHLIST, m_searchlist);
	DDX_Control(pDX, IDC_EDIT_QSEARCH, m_edQSearch);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CSearch, CDialog)
	//{{AFX_MSG_MAP(CSearch)
	ON_BN_CLICKED(IDC_CLEAR, OnClear)
	ON_NOTIFY(NM_DBLCLK, IDC_SEARCHLIST, OnDblclkSearchlist)
	//}}AFX_MSG_MAP
	ON_EN_CHANGE(IDC_EDIT_QSEARCH, OnEnChangeEditQsearch)
	ON_NOTIFY(NM_CLICK, IDC_SEARCHLIST, OnNMClickSearchlist)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSearch message handlers

BOOL CSearch::OnInitDialog() 
{
	CDialog::OnInitDialog();

	m_edQSearch.SetFocus();

	if (!m_bSenatt)
	{
		SqlExecutionAndList();
	}
	else
	{
		SqlExecution();		 
		if (m_bDataFound) { CustomizedList(); }
		else 
		{ 
			m_sSecondCode = ""; 
			CDialog::OnOK();
		}
	
	// If this is a RICHEDIT control, the control, OnEnChangeEditQsearch(), will not
	// send this notification unless you override the CDialog::OnInitDialog()
	// function and call CRichEditCtrl().SetEventMask()
	// with the ENM_CHANGE flag ORed into the mask.
	//	CRichEditCtrl().SetEventMask(ENM_CHANGE);
	}
	return FALSE; //TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}	// OnQury

void CSearch::SetColumnNames(const CString sN0, const CString sN1, const CString sN2, const CString sN3 )
{
	m_sColName0 = sN0;
	m_sColName1 = sN1;
	m_sColName2 = sN2;
	m_sColName3 = sN3;
}	// SetColumnNames

void CSearch::SqlExecutionAndList()
{
	m_searchlist.SetHighlightType(HIGHLIGHT_ROW);
	m_searchlist.EnableSort ();
	m_searchlist.SetColumnTypes (_gnLogColTypes, NUM_LOGCOLUMNS);

	m_searchlist.InsertColumn (0,"Code",LVCFMT_LEFT, 40);
	m_searchlist.InsertColumn (1,"Description",LVCFMT_LEFT, 187);
	m_searchlist.InsertColumn (2,"Comments", LVCFMT_LEFT, 97);
	m_searchlist.InsertColumn (3,"Code Name", LVCFMT_LEFT, 90);

	CString SQLSelect;

	//Set up SQL Select statement based on which search button was pressed.
	if (m_SQLSelect =="")
	{
	    SQLSelect = "SELECT " + m_codename + ", " + m_codename + "D, " + m_codename+"_COMMENT FROM NHTSADB_"+
			         m_codename + " WHERE REFERENCE LIKE '%" + m_db  + "%' ORDER BY " + m_codename;
	}
	else
	{
		SQLSelect = m_SQLSelect;
	}

	// ado:
	_bstr_t bstrQuery(SQLSelect);
//	_variant_t vtQuery( SQLSelect ); // for debug only
	_variant_t vRecsAffected(0L);

	_RecordsetPtr pRecordSet;
	try
	{
//		_variant_t vtString = CEntreeV5App::m_pConnection->ConnectionString; // for debug only

		pRecordSet= CEntreeV5App::m_pConnection->Execute(bstrQuery, &vRecsAffected, adOptionUnspecified);

		if (!pRecordSet->GetadoEOF())
		{
			_variant_t vCodenameIdx(m_codename);
			_variant_t vCodedescIdx(m_codename+"D");
			_variant_t vCodecommIdx(m_codename+"_COMMENT");

			int i = 0;
			while (!pRecordSet->GetadoEOF()) // while not end of dataset
			{
				AddItemToList( pRecordSet, vCodenameIdx, i, 0);
				AddItemToList( pRecordSet, vCodedescIdx, i, 1);
				AddItemToList( pRecordSet, vCodecommIdx, i, 2);
				AddItemToList( pRecordSet, vCodenameIdx, i, 3);
				i++;
				pRecordSet->MoveNext();
			}
			m_bDataFound = true;
		}
		else
		{
			MessageBox("No Data Found.");
			m_bDataFound = false;
		}

		pRecordSet->Close();
	}
	catch (_com_error *e) //handle com errors
	{
		// Get info from _com_error
		CString Error = e->ErrorMessage();
		AfxMessageBox(e->ErrorMessage());
						
	}
	catch (...)  //handle all other errors.  See codeguru->Database->ADO is AOK, Dmitri's response.
	{
		ErrorPtr errItem;
		_variant_t vIndex;
		_bstr_t strstr;
		long iNum=0;

		CEntreeV5App::m_pConnection -> Errors -> get_Count(&iNum);
	
		for(int i = 0; i < iNum; i++)
		{
			vIndex.vt = VT_I4;
			vIndex.lVal = i;
			errItem = CEntreeV5App::m_pConnection -> Errors ->GetItem(vIndex);
			strstr = errItem -> Description;
			AfxMessageBox(strstr);
		}

	}
}	// SqlExecutionAndList

void CSearch::SqlExecution()
{
	CString SQLSelect;

	//Set up SQL Select statement based on which search button was pressed.
	if (m_SQLSelect =="")
	{
	    SQLSelect = "SELECT " + m_codename + ", " + m_codename + "D, " + m_codename+"_COMMENT FROM NHTSADB_"+
			         m_codename + " WHERE REFERENCE LIKE '%" + m_db  + "%' ORDER BY " + m_codename;
	}
	else
	{
		SQLSelect = m_SQLSelect;
	}

	// ado:
	_bstr_t bstrQuery(SQLSelect);
//	_variant_t vtQuery( SQLSelect ); // for debug only
	_variant_t vRecsAffected(0L);

	_RecordsetPtr pRecordSet;
	try
	{
//		_variant_t vtString = CEntreeV5App::m_pConnection->ConnectionString; // for debug only

		pRecordSet= CEntreeV5App::m_pConnection->Execute(bstrQuery, &vRecsAffected, adOptionUnspecified);

		if (!pRecordSet->GetadoEOF())
		{
			if (!m_bSenatt)
			{
				_variant_t vCodenameIdx(m_codename);
				_variant_t vCodedescIdx(m_codename+"D");
				_variant_t vCodecommIdx(m_codename+"_COMMENT");

				int i = 0;
				while (!pRecordSet->GetadoEOF()) // while not end of dataset
				{
					AddItemToArray( pRecordSet, vCodenameIdx, i, 0);
					AddItemToArray( pRecordSet, vCodedescIdx, i, 1);
					AddItemToArray( pRecordSet, vCodecommIdx, i, 2);
					AddItemToArray( pRecordSet, vCodenameIdx, i, 3);
					i++;
					pRecordSet->MoveNext();
				}
			}
			else
			{
				_variant_t vCodenameIdx(m_sColName0);
				_variant_t vCodedescIdx(m_sColName1);
				_variant_t vCodecommIdx(m_sColName2);
				_variant_t vCodecomm1Idx(m_sColName3);

				int i = 0;
				while (!pRecordSet->GetadoEOF()) // while not end of dataset
				{
					AddItemToArray( pRecordSet, vCodenameIdx, i, 0);
					AddItemToArray( pRecordSet, vCodedescIdx, i, 1);
					AddItemToArray( pRecordSet, vCodecommIdx, i, 2);
					AddItemToArray( pRecordSet, vCodecomm1Idx, i, 3);
					i++;
					pRecordSet->MoveNext();
				}
			}
			m_bDataFound = true;
		}
		else
		{
			if (m_bSenatt) { MessageBox("No related SENLOC Data Found for this UNIT."); }
			else { MessageBox("No Data Found."); }
			m_bDataFound = false;
		}

		pRecordSet->Close();
	}
	catch (_com_error *e) //handle com errors
	{
		// Get info from _com_error
		CString Error = e->ErrorMessage();
		AfxMessageBox(e->ErrorMessage());
						
	}
	catch (...)  //handle all other errors.  See codeguru->Database->ADO is AOK, Dmitri's response.
	{
		ErrorPtr errItem;
		_variant_t vIndex;
		_bstr_t strstr;
		long iNum=0;

		CEntreeV5App::m_pConnection -> Errors -> get_Count(&iNum);
	
		for(int i = 0; i < iNum; i++)
		{
			vIndex.vt = VT_I4;
			vIndex.lVal = i;
			errItem = CEntreeV5App::m_pConnection -> Errors ->GetItem(vIndex);
			strstr = errItem -> Description;
			AfxMessageBox(strstr);
		}

	}
}	// SqlExecution

void CSearch::StoredProcExecution()
{
	CAdoStoredProcExe* pSP = new CAdoStoredProcExe(CEntreeV5App::m_pConnection);
	_variant_t pRS = pSP->ADOExecuteSP(m_storedproc, m_parameter);
	_RecordsetPtr pRecordSet = pRS;
///////////////
	m_codename = "REGION";
		if (!pRecordSet->GetadoEOF())
		{
			_variant_t vCodenameIdx(m_codename);
			_variant_t vCodedescIdx(m_codename+"d");
			_variant_t vCodecommIdx(m_codename+"_COMMENT");

			CString sData;
			int i = 0;
			while (!pRecordSet->GetadoEOF())
			{

			_variant_t vData = pRecordSet->GetCollect(vCodenameIdx);
			sData =(char*)_bstr_t(vData);
			vData = pRecordSet->GetCollect(vCodedescIdx);
			sData =(char*)_bstr_t(vData);

				i++;
				pRecordSet->MoveNext();
			}
		}
		else
		{
			MessageBox("No Data Found.");
		}

		pRecordSet->Close();
////////////////////
	try
	{
		_CommandPtr pCommand; 
		pCommand.CreateInstance(__uuidof(Command));
		_variant_t vNull, vData;
		vNull.vt = VT_NULL;

		pCommand->ActiveConnection = CEntreeV5App::m_pConnection;
		pCommand->CommandType = adCmdStoredProc; 
		pCommand->CommandText = _bstr_t( m_storedproc );

		_bstr_t bsParameter = m_parameter;
		_variant_t vRecsAffected; vRecsAffected.vt = VT_INT;
		_variant_t vParameter; vParameter = m_parameter;
		_RecordsetPtr pRecordSet = pCommand->Execute( &vRecsAffected, &vParameter, adCmdStoredProc);


		m_codename = "REGION";
		if (!pRecordSet->GetadoEOF())
		{
			_variant_t vCodenameIdx(m_codename);
			_variant_t vCodedescIdx(m_codename+"d");
			_variant_t vCodecommIdx(m_codename+"_COMMENT");

			CString sData;
			int i = 0;
			while (!pRecordSet->GetadoEOF())
			{

			_variant_t vData = pRecordSet->GetCollect(vCodenameIdx);
			sData =(char*)_bstr_t(vData);
			vData = pRecordSet->GetCollect(vCodedescIdx);
			sData =(char*)_bstr_t(vData);
			vData = pRecordSet->GetCollect(vCodecommIdx);
			sData =(char*)_bstr_t(vData);
			sData =(char*)_bstr_t(vCodenameIdx);

//				AddItemToList( pRecordSet, vCodenameIdx, i, 0);
///				AddItemToList( pRecordSet, vCodedescIdx, i, 1);
//				AddItemToList( pRecordSet, vCodecommIdx, i, 2);
//				AddItemToList( pRecordSet, vCodenameIdx, i, 3);
				i++;
				pRecordSet->MoveNext();
			}
		}
		else
		{
			MessageBox("No Data Found.");
		}

		pRecordSet->Close();
	}
	catch (_com_error *e) //handle com errors
	{
		// Get info from _com_error
		CString Error = e->ErrorMessage();
		AfxMessageBox(e->ErrorMessage());
						
	}
	catch (...)  //handle all other errors.  See codeguru->Database->ADO is AOK, Dmitri's response.
	{
		ErrorPtr errItem;
		_variant_t vIndex;
		_bstr_t strstr;
		long iNum=0;

		CEntreeV5App::m_pConnection -> Errors -> get_Count(&iNum);
	
		for(int i = 0; i < iNum; i++)
		{
			vIndex.vt = VT_I4;
			vIndex.lVal = i;
			errItem = CEntreeV5App::m_pConnection -> Errors ->GetItem(vIndex);
			strstr = errItem -> Description;
			AfxMessageBox(strstr);
		}

	}
}	// StoredProcExecution

// Set the global search_code with the selected code.
void CSearch::OnOK() 
{
	int pos= (int) m_searchlist.GetFirstSelectedItemPosition (); // return '1' base index

	//Global search_code.
	if (pos<1) { CDialog::OnCancel(); return; }
	search_code = m_searchlist.GetItemText(pos-1,0);
	search_code.TrimLeft();
	search_code.TrimRight();
	if (m_bSenatt)
	{
		m_sSecondCode = m_searchlist.GetItemText(pos-1,1);
		m_sSecondCode = m_sSecondCode.Left(m_sSecondCode.Find("("));
	}
	CDialog::OnOK();
}

void CSearch::OnClear() 
{
	search_code = "";

	CDialog::OnOK();
	
}

void CSearch::OnDblclkSearchlist(NMHDR* pNMHDR, LRESULT* pResult) 
{
	OnOK(); 
	
	*pResult = 0;
}

// ------------
// void CSearch::AddItemToList(...)
// 
// add an item to control list
// ------------
void CSearch::AddItemToList( _RecordsetPtr pRecs, const _variant_t & pItem, const int nRow, const int nCol)
{
	CString sData;
	try 
	{
		// compute sData:
		if (nCol==3)
		{
			sData =(char*)_bstr_t(pItem);
		}
		else
		{
			_variant_t vData = pRecs->GetCollect(pItem);
			sData =(char*)_bstr_t(vData);
		}
		// insert data:	
		sData.Trim();
		if (nCol==0) { m_searchlist.InsertItem ( nRow, sData); }
		else { m_searchlist.SetItemText( nRow, nCol, sData); }
	}
	catch (_com_error* e)
	{
		// Get info from _com_error
		CString Error = e->ErrorMessage();
		AfxMessageBox(e->ErrorMessage());
	}
	catch (...)//handle all other errors.  See codeguru->Database->ADO is AOK, Dmitri's response.
	{
		ErrorPtr errItem;
		_variant_t vIndex;
		_bstr_t strstr;
		long iNum=0;
		CEntreeV5App::m_pConnection -> Errors -> get_Count(&iNum);
		
		for(int i = 0; i < iNum; i++)
		{
			vIndex.vt = VT_I4;
			vIndex.lVal = i;
			errItem = CEntreeV5App::m_pConnection -> Errors ->GetItem(vIndex);
			strstr = errItem -> Description;
			AfxMessageBox(strstr);
		}
	}

}	// AddItemToList

// ------------
// void CSearch::AddItemToArray(...)
// 
// add items to arrays
// ------------
void CSearch::AddItemToArray( _RecordsetPtr pRecs, const _variant_t & pItem, const int nRow, const int nCol)
{
	CString sData;
	try 
	{
		// compute sData:
		if (nCol==3)
		{
			sData =(char*)_bstr_t(pItem);
		}
		else
		{
			_variant_t vData = pRecs->GetCollect(pItem);
			sData =(char*)_bstr_t(vData);
		}
		// insert data:	
		sData.Trim();
		switch (nCol)
		{
		case 0: Array0.Add(sData); break;
		case 1: Array1.Add(sData); break;
		case 2: Array2.Add(sData); break;
		case 3: Array3.Add(sData); break;
		}
	}
	catch (_com_error* e)
	{
		// Get info from _com_error
		CString Error = e->ErrorMessage();
		AfxMessageBox(e->ErrorMessage());
	}
	catch (...)//handle all other errors.  See codeguru->Database->ADO is AOK, Dmitri's response.
	{
		ErrorPtr errItem;
		_variant_t vIndex;
		_bstr_t strstr;
		long iNum=0;
		CEntreeV5App::m_pConnection -> Errors -> get_Count(&iNum);
		
		for(int i = 0; i < iNum; i++)
		{
			vIndex.vt = VT_I4;
			vIndex.lVal = i;
			errItem = CEntreeV5App::m_pConnection -> Errors ->GetItem(vIndex);
			strstr = errItem -> Description;
			AfxMessageBox(strstr);
		}
	}

}	// AddItemToArray

void CSearch::CustomizedList()
{
	m_searchlist.SetHighlightType(HIGHLIGHT_ROW);
	m_searchlist.EnableSort ();
	m_searchlist.SetColumnTypes (_gnLogColTypes, NUM_LOGCOLUMNS);

	m_searchlist.InsertColumn (0,m_sColName0,LVCFMT_LEFT, 50);
	m_searchlist.InsertColumn (1,m_sColName1,LVCFMT_LEFT, 180);
	m_searchlist.InsertColumn (2,m_sColName2, LVCFMT_LEFT,110);
	m_searchlist.InsertColumn (3,m_sColName3, LVCFMT_LEFT, 90);

	CStringArray Arr0;
	CStringArray Arr1;
	CStringArray Arr2;
	CStringArray Arr3;

	for (int i=0; i<Array0.GetSize(); i++)
	{
		Arr0.Add(Array0[i]);
		Arr1.Add(Array1[i]);
		Arr2.Add(Array2[i]);
		Arr3.Add(Array3[i]);
	}

	Array0.RemoveAll();
	Array1.RemoveAll();
	Array2.RemoveAll();
	Array3.RemoveAll();

	m_codename = "SENLOC";
	m_db = "BIODB";
	m_SQLSelect = "SELECT " + m_codename + ", " + m_codename + "D, " + m_codename+"_COMMENT FROM NHTSADB_"+
			         m_codename + " WHERE REFERENCE LIKE '%" + m_db  + "%' ORDER BY " + m_codename;
	m_bSenatt = false;
	SqlExecution();
	for ( i=0; i<Arr0.GetSize(); i++)
	{
		m_searchlist.InsertItem ( i, Arr0[i]);
		m_searchlist.SetItemText( i, 1, sSenloc(Arr1[i],Array0,Array1));
		m_searchlist.SetItemText( i, 2, Arr2[i]);
		m_searchlist.SetItemText( i, 3, Arr3[i]);
	}
	m_bSenatt = true;
}	// CustomizedList

const CString CSearch::sSenloc(const CString sSenl, CStringArray& sArr0, CStringArray& sArr1)
{
	CString sOut("");
	for (int i=0; i<sArr0.GetSize(); i++)
	{
		if (sSenl==sArr0[i])
		{
			sOut = sSenl + " ( " + sArr1[i] + " )";
			break;
		}
	}

	return sOut;
}	// sSenloc

void CSearch::OnEnChangeEditQsearch()
{
	// If this is a RICHEDIT control, the control will not
	// send this notification unless you override the CDialog::OnInitDialog()
	// function and call CRichEditCtrl().SetEventMask()
	// with the ENM_CHANGE flag ORed into the mask.

	m_edQSearch.GetWindowText(m_sQCode);
	m_sQCode.Trim();
	m_sQCode.MakeUpper();
	int nQCode = m_sQCode.GetLength();
	if ( (m_sQCode=="")||(m_sOldQCode ) == m_sQCode) { return; }

	CString current_code("");
	int n = m_searchlist.GetItemCount();
	for (int i=0; i<n; i++)	// find matching in the first string
	{
		current_code = m_searchlist.GetItemText(i,0);
		if (current_code.Left(nQCode).CompareNoCase(m_sQCode)==0)
		{ 
			m_searchlist.EnsureVisible(i, FALSE);
			m_searchlist.SetItemState(i, LVIS_SELECTED, LVIS_SELECTED);
			break;
		}
	}

	m_sOldQCode = m_sQCode;

}	// OnEnChangeEditQsearch


void CSearch::OnNMClickSearchlist(NMHDR *pNMHDR, LRESULT *pResult)
{
	*pResult = 0;
}
