// -----------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: SWGData.cpp
//
// Author: Dan Robbins
//
// Date Created: October, 1998
//
// Description:  SWGData constructors and member functions to
//               process, import and export data.
// -----------------------------------------


#include "stdafx.h"
#include "entreeV5.h"
#include "SWGData.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
CSWGData::CSWGData()
{
	// initialize members.  The arrays are 0 based, but the zeroth entry will not be used
	// because curve number (which starts at 1) is used as an index.  So, initialize 0 and 1.
	m_axis.SetAtGrow(0,""); m_axis.SetAtGrow (1, "");
	m_cerdat = "";
    m_chlmax.SetAtGrow ( 0, "" ); m_chlmax.SetAtGrow( 1, "" );
	m_chstat.SetAtGrow(0,""); m_chstat.SetAtGrow (1, "");
	m_conno = "";
	m_dastat.SetAtGrow(0,""); m_dastat.SetAtGrow (1, "");
	m_delt.SetAtGrow( 0, "" ); m_delt.SetAtGrow (1, "");
	m_inscom.SetAtGrow(0,""); m_inscom.SetAtGrow (1, "");
	m_insrat.SetAtGrow( 0, "" ); m_insrat.SetAtGrow (1, "");
	m_link = "";
	m_nfp.SetAtGrow( 0, "" ); m_nfp.SetAtGrow (1, "");
	m_nlp.SetAtGrow( 0, "" ); m_nlp.SetAtGrow (1, "");
	m_prefil.SetAtGrow( 0, "" ); m_prefil.SetAtGrow (1, "");
	m_rectyp = "";
	m_senatt.SetAtGrow( 0,"" ); m_senatt.SetAtGrow (1, "");
    m_senloc.SetAtGrow( 0,"" ); m_senloc.SetAtGrow (1, "");
	m_sentyp.SetAtGrow( 0,"" ); m_sentyp.SetAtGrow (1, "");
	m_siglev.SetAtGrow( 0,"5" ); m_siglev.SetAtGrow (1, "5");
	m_sigsrc.SetAtGrow( 0,"" ); m_sigsrc.SetAtGrow (1, "");
	m_swgno	= "";
	m_temp	= "";
	m_title = "";
	m_totcrv = 0;
	m_tstcom = "";
	m_tstdat = "";
	m_tstobj = "";
	m_tstprf = "";
	m_tstref = "";
	m_tsttyp = "";
	m_verno = "S5";
	m_xunits.SetAtGrow(0,"SEC"); m_xunits.SetAtGrow (1, "SEC");
	m_yunits.SetAtGrow(0,""); m_yunits.SetAtGrow (1, "");
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
CSWGData::~CSWGData()
{

}

//******************
// ExportEV5 
// This function creates a .ev5 file and writes the data in SWGData out to it. 
// *****************
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
BOOL CSWGData::ExportEV5(CString & strfile_out)
{

		
	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_out, CFile::modeCreate | CFile::modeReadWrite | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return FALSE;
	}
	
	CTime now = CTime::GetCurrentTime ();
	myFile.WriteString ("# Source: Entree for Windows v5\n");
	CString strToday;
	strToday.Format("# Date: <%d/%d/%d>\n", now.GetMonth(), now.GetDay(), now.GetYear() );
	myFile.WriteString (strToday);
	myFile.WriteString ("----- EV5 -----\n");

	WriteSWGTest(myFile);
	WriteSWGInst(myFile);

	myFile.WriteString ("----- END -----\n");

	myFile.Close ();

	
	return TRUE;
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
CString CSWGData::OutString(CString str)
{
	if (str=="")
	{
		str=" |";
	}
	else
	{
		str+= "|";
	}
	
	return str;
}	

/******************************************************************************

	Name:		WriteSWGTest	

	Action:		Write EV5 Test info in a standardized order.

	Params:		CStdioFile & myFile

	Returns:	void

	Notes:		Last String in SWGTest, dont use OutString to append |, 
				instead append a \n.

	Dates:

******************************************************************************/
void CSWGData::WriteSWGTest( CStdioFile & myFile )
{	
	// If no data in test screen, then do not print this section.
	if( ValidateEmptyTest() == true )
	{
		return;
	}

	myFile.WriteString ("----- TEST -----\n");
	
	CString cstrTemp("");
	
	if (m_verno=="") m_verno.Format( "S5" );
	myFile.WriteString( OutString( m_verno ) );
	myFile.WriteString( OutString( m_swgno ) );
	myFile.WriteString( OutString( m_title ) );	
	myFile.WriteString( OutString( m_tstobj ) );

	m_tstdat.MakeUpper();
	myFile.WriteString( OutString( m_tstdat ) );

	m_cerdat.MakeUpper();
	myFile.WriteString( OutString( m_cerdat ) );
	myFile.WriteString( OutString( m_tstprf ) );	
	myFile.WriteString( OutString( m_conno ) );	
	myFile.WriteString( OutString( m_tstref ) );
	myFile.WriteString( OutString( m_tsttyp ) );
	myFile.WriteString( OutString( m_temp ) );
	myFile.WriteString( OutString( m_rectyp ) );
	myFile.WriteString( OutString( m_link ) );	

	cstrTemp.Format( "%d", m_totcrv );
	myFile.WriteString( OutString( cstrTemp ));
	myFile.WriteString( m_tstcom+'\n');
}

/******************************************************************************

	Name:		ValidateEmptyTest

	Action:		

	Params:		void

	Returns:	bool

	Notes:		Returns true, if the fields are empty and false, if at least
				one is has information.

	Dates:		Created -- Al Wilhelm -- 03/17/2000

******************************************************************************/
bool CSWGData::ValidateEmptyTest( void )
{
	if(		( m_swgno.IsEmpty() == TRUE )
		&&	( m_title.IsEmpty() == TRUE )
		&&	( m_tstobj.IsEmpty() == TRUE )
		&&	( m_tstprf.IsEmpty() == TRUE )
		&&	( m_conno.IsEmpty() == TRUE )
		&&	( m_tstref.IsEmpty() == TRUE )
		&&	( m_tsttyp.IsEmpty() == TRUE )
		&&	( m_temp.IsEmpty() == TRUE )
		&&	( m_rectyp.IsEmpty() == TRUE )
		&&	( m_link.IsEmpty() == TRUE )
		&&	( m_tstcom.IsEmpty() == TRUE ) )
	{
		return true;
	}

	return false;
}

/******************************************************************************

	Name:		WriteSWGInst	

	Action:		

	Params:		CStdioFile & myFile

	Returns:	void

	Notes:		Last String in SWGInst, dont use OutString to append |,
				instead append a \n.

	Dates:

******************************************************************************/
void CSWGData::WriteSWGInst( CStdioFile & myFile )
{
	// If total curves is zero, then do not print out this section.
	if( m_curno <= 0 )
	{
		return;
	}

	myFile.WriteString( "----- INSTRUMENTATION -----\n" );
	
	char temp [100];
	for( int loop = 1;loop <= m_curno; loop++ )
	{
		itoa(loop,temp,10);
		myFile.WriteString(	OutString( temp));
		myFile.WriteString(	OutString( m_sigsrc[loop]));
		myFile.WriteString(	OutString( m_siglev[loop]));
		myFile.WriteString(	OutString( m_sentyp[loop]));
		myFile.WriteString(	OutString( m_senloc[loop]));
		myFile.WriteString(	OutString( m_senatt[loop]));
		myFile.WriteString(	OutString( m_axis[loop]));
		myFile.WriteString(	OutString( m_xunits[loop]));
		myFile.WriteString(	OutString( m_yunits[loop]));
		myFile.WriteString(	OutString( m_prefil[loop]));
		myFile.WriteString(	OutString( m_insrat[loop]));
		myFile.WriteString(	OutString( m_chlmax[loop]));
		myFile.WriteString(	OutString( m_nfp[loop]));
		myFile.WriteString(	OutString( m_nlp[loop]));
		myFile.WriteString(	OutString( m_delt[loop]));
		myFile.WriteString(	OutString( m_dastat[loop]));
		myFile.WriteString(	OutString( m_chstat[loop] ) );
		myFile.WriteString(	m_inscom[loop]+'\n');
	}
}

/******************************************************************************

	Name:		ExportEVR	

	Action:		Create a Report (.evr) from the current SWG Data

	Params:		CString & strfile_out

	Returns:	BOOL

	Notes:	

	Dates:

******************************************************************************/
BOOL CSWGData::ExportEVR( CString & strfile_out )
{

	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_out, CFile::modeCreate | CFile::modeReadWrite | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return FALSE;
	}
	
	CTime now = CTime::GetCurrentTime ();
	myFile.WriteString ("# Source: Entree for Windows v5\n");
	CString strToday;
	strToday.Format("# Date: <%d/%d/%d>\n", now.GetMonth(), now.GetDay(), now.GetYear() );
	myFile.WriteString (strToday);
	myFile.WriteString ("----- EV5 REPORT FILE -----\n");

	WriteSWGTestReport(myFile);
	WriteSWGInstReport(myFile);

	myFile.WriteString ("----- END -----\n");

	myFile.Close ();


	return TRUE;
}

//Write the SWGTest Part of a Report (evr) file
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGData::WriteSWGTestReport(CStdioFile & myFile)
{
	// If no data in test screen, then do not print this section.
	if( ValidateEmptyTest() == true )
	{
		return;
	}

	CString strTotCrv("");

	myFile.WriteString ("----- TEST -----\n");
	myFile.WriteString ("Version Number:	"+m_verno+"\n");
	myFile.WriteString ("Wave Generator Serial Number:	"+m_swgno+"\n");
	myFile.WriteString ("Test Title:	"+m_title+"\n");	
	myFile.WriteString ("Test Objectives:	"+m_tstobj+"\n");
	myFile.WriteString ("Test Date:	"+m_tstdat+"\n");
	myFile.WriteString ("Certification Date:	"+m_cerdat+"\n");
	myFile.WriteString ("Test Performer:	"+m_tstprf+"\n");	
	myFile.WriteString ("Contract Number:	"+m_conno+"\n");	
	myFile.WriteString ("Test Reference Number:	"+m_tstref+"\n");
	myFile.WriteString ("Test Type:	"+m_tsttyp+"\n");
	myFile.WriteString ("Ambient Temperature:	"+m_temp+"\n");
	myFile.WriteString ("Recorder Type:	"+m_rectyp+"\n");
	myFile.WriteString ("Data Link Type:	"+m_link+"\n");	
	
	strTotCrv.Format( "%d", m_totcrv );
	myFile.WriteString ("Total Number of Curves:	" + strTotCrv + "\n" );
	myFile.WriteString ("Test Comments:	"+m_tstcom+"\n");
}

/******************************************************************************

	Name:		

	Action:		Write the SWGInst part of a report (evr) file

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGData::WriteSWGInstReport(CStdioFile & myFile)
{
	// If total curves is zero, then do not print out this section.
	if( m_curno <= 0 )
	{
		return;
	}

	CString strTemp("");

	myFile.WriteString ("----- INSTRUMENTATION -----\n");

	for( int loop = 1;loop <= m_curno; loop++ )
	{
		strTemp.Format( "%d", loop );
		myFile.WriteString ("----- CURVE NUMBER "+strTemp+" -----\n");
		myFile.WriteString ("Signal Source:	"+m_sigsrc[loop]+"\n");
		myFile.WriteString ("Level:	"+m_siglev[loop]+"\n");
		myFile.WriteString ("Sensor Type:	"+m_sentyp[loop]+"\n");
		myFile.WriteString ("Sensor Location:	"+m_senloc[loop]+"\n");
		myFile.WriteString ("Sensor Attachment:	"+m_senatt[loop]+"\n");
		myFile.WriteString ("Axis Direction of Sensor:	"+m_axis[loop]+"\n");
		myFile.WriteString ("Data Measurement XUnits:	"+m_xunits[loop]+"\n");
		myFile.WriteString ("Data Measurement YUnits:	"+m_yunits[loop]+"\n");
		myFile.WriteString ("Prefilter Frequency:	"+m_prefil[loop]+"\n");
		myFile.WriteString ("Instrument Rating:	"+m_insrat[loop]+"\n");
		myFile.WriteString ("Channel Maximum Rating:	"+m_chlmax[loop]+"\n");
		myFile.WriteString ("Number of First Point:	"+m_nfp[loop]+"\n");
		myFile.WriteString ("Number of Last Point:	"+m_nlp[loop]+"\n");
		myFile.WriteString ("Time Increment:	"+m_delt[loop]+"\n");
		myFile.WriteString ("Data Status:	"+m_dastat[loop]+"\n");
		myFile.WriteString ("Channel Status:	"+m_chstat[loop]+"\n");
		myFile.WriteString ("Instrument Comments:	"+m_inscom[loop]+"\n");
	}
}

/******************************************************************************

	Name:		

	Action:		Open an EV5 file to read in the data.

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
BOOL CSWGData::ImportEV5(CString & strfile_in)
{
	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_in, CFile::modeRead | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_in, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return FALSE;
	}

	ExtractTestData(myFile, EV5);  //SWGTest is the same in ev5 and ev4
	ExtractCurveData (myFile, EV5);

	return TRUE;
}

// Put data from ev4 file into SWGData member variables.
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
BOOL CSWGData::ImportEV4(CString & strfile_in)
{
	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_in, CFile::modeRead | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_in, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return FALSE;
	}
	
	ExtractTestData(myFile, EV4);  //SWGTest is the same in ev5 and ev4
	ExtractCurveData (myFile, EV4);
	
	return TRUE;
}

// -------
// void CSWGData::ExtractCurveData(CStdioFile, int)  
//
// description:  verify proper format of the file and get info out of INST section
// -----
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGData::ExtractCurveData(CStdioFile &myFile, int nVersion)
{
	CString strLine;
	myFile.SeekToBegin ();  // back to beginning

	// find ----- INSTRUMENTATION -----
	int nRes =-1;
	while (myFile.ReadString (strLine))
	{
		nRes = strLine.Find("----- INSTRUMENTATION -----");
		if (nRes != -1) break;
	}

	if (nRes == -1)   // INSTRUMENTATION section not found
	{
		m_totcrv = 0;
		return;
	}
	 
	// now read line after ----- INSTRUMENTATION -----
	myFile.ReadString (strLine);	

	if ((strLine.GetLength ()) <1) 
	{
		m_totcrv=0;
		return;  // don't process empty string
	}

	while (strLine[0]=='#')  //comment line, so read another.
	{
		myFile.ReadString (strLine);	
	}


	int loc1 = strLine.Find ('|',0);

	if (loc1==-1) 
	{
		m_totcrv=0;
		return;      // | not found in line after ----- INSTRUMENTATION -----,
				     // must be another section, so return.
	}

	int loop =1;
	while ((strLine.Left(6) !="----- "))  // not at another header.
	{
		//17 pipes.EV5 and  16 EV4
		int nPipes = CountPipes(strLine);
		if (nVersion==EV5)
		{
			if (nPipes!= 17)
			{
				char buf [10];
				itoa (nPipes,buf,10);
				CString strPipes = buf;
				CString strErr = "This EV5 file has "+strPipes +" | characters in the INSTRUMENTATION section, should have 17.";
				MessageBox(NULL, strErr, "Error",MB_OK);
				m_totcrv=0;
				return;
			}
		}
		else if (nVersion == EV4)
		{
//			if (nPipes!= 16)
			if (nPipes!= 17)	// wong corrected
			{
				
				char buf [10];
				itoa (nPipes,buf,10);
				CString strPipes = buf;
				CString strErr = "This EV4 file has "+strPipes +" | characters in the INSTRUMENTATION section, should have 17.";
				MessageBox(NULL, strErr, "Error",MB_OK);
				m_totcrv=0;
				return;
			}
		}
		
		// EV4, skip TSTNO.
		if (nVersion == EV4)
		{
			m_curno = atoi(GetTextBetweenPipes(strLine,1,2));
			m_sigsrc.SetAtGrow (loop, GetTextBetweenPipes(strLine,2,3));
			m_siglev.SetAtGrow (loop, GetTextBetweenPipes(strLine,3,4));
			m_sentyp.SetAtGrow (loop, GetTextBetweenPipes(strLine,4,5));
			m_senloc.SetAtGrow (loop, GetTextBetweenPipes(strLine,5,6));
			m_senatt.SetAtGrow (loop, GetTextBetweenPipes(strLine,6,7));
			m_axis.SetAtGrow (loop, GetTextBetweenPipes(strLine,7,8));
			m_xunits.SetAtGrow (loop, _T("SEC"));	// corrected by wong
			m_yunits.SetAtGrow (loop, GetTextBetweenPipes(strLine,8,9) );
			m_prefil.SetAtGrow (loop, GetTextBetweenPipes(strLine,9,10) );
			m_insrat.SetAtGrow (loop, GetTextBetweenPipes(strLine,10,11) );
			m_chlmax.SetAtGrow (loop, GetTextBetweenPipes(strLine,11,12));
			m_nfp.SetAtGrow (loop, GetTextBetweenPipes(strLine,12,13));
			m_nlp.SetAtGrow (loop, GetTextBetweenPipes(strLine,13,14));
			m_delt.SetAtGrow (loop, GetTextBetweenPipes(strLine,14,15));
			m_dastat.SetAtGrow (loop, GetTextBetweenPipes(strLine,15,16));
			m_chstat.SetAtGrow (loop, GetTextBetweenPipes(strLine,16,17));
			m_inscom.SetAtGrow (loop, GetTextBetweenPipes(strLine,17,18));
		}
		else //EV5, no tstno in file, so don't skip
		{
			m_curno = atoi(GetTextBetweenPipes(strLine,0,1));
			m_sigsrc.SetAtGrow (loop, GetTextBetweenPipes(strLine,1,2));
			m_siglev.SetAtGrow (loop, GetTextBetweenPipes(strLine,2,3));
			m_sentyp.SetAtGrow (loop, GetTextBetweenPipes(strLine,3,4));
			m_senloc.SetAtGrow (loop, GetTextBetweenPipes(strLine,4,5));
			m_senatt.SetAtGrow (loop, GetTextBetweenPipes(strLine,5,6));
			m_axis.SetAtGrow (loop, GetTextBetweenPipes(strLine,6,7));
			m_xunits.SetAtGrow (loop, GetTextBetweenPipes(strLine,7,8));
			m_yunits.SetAtGrow (loop, GetTextBetweenPipes(strLine,8,9));
			m_prefil.SetAtGrow (loop, GetTextBetweenPipes(strLine,9,10));
			m_insrat.SetAtGrow (loop, GetTextBetweenPipes(strLine,10,11));
			m_chlmax.SetAtGrow (loop, GetTextBetweenPipes(strLine,11,12));
			m_nfp.SetAtGrow (loop, GetTextBetweenPipes(strLine,12,13));
			m_nlp.SetAtGrow (loop, GetTextBetweenPipes(strLine,13,14));
			m_delt.SetAtGrow (loop, GetTextBetweenPipes(strLine,14,15));
			m_dastat.SetAtGrow (loop, GetTextBetweenPipes(strLine,15,16));
			m_chstat.SetAtGrow (loop, GetTextBetweenPipes(strLine,16,17));
			m_inscom.SetAtGrow (loop, GetTextBetweenPipes(strLine,17,18));
		}

		// now increment loop and read next line
		loop++;
		myFile.ReadString (strLine);

		while (strLine[0]=='#')  //comment line, so read another.
		{
			myFile.ReadString (strLine);	
		}

	}
	m_totcrv = loop-1;  // total curve infos read from file.
	
}

// --------
// void CSWGData::ExtractTestData(CStdioFile, int) 
//
// description: verify proper format of the file and get info out of test section
// --------
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGData::ExtractTestData(CStdioFile &myFile, int nVersion)
{
	CString strLine;
	myFile.SeekToBegin ();  // back to beginning

	// find ----- TEST -----
	int nRes = -1;
	while (myFile.ReadString (strLine))
	{
		nRes = strLine.Find("----- TEST -----");
		if (nRes != -1) break;
	}

	if (nRes == -1) return;  // TEST section not found
    // now read line after ----- TEST -----
	
	myFile.ReadString (strLine);	
	if ((strLine.GetLength ()) <1) return;  // don't process empty string

	while (strLine[0]=='#')  //comment line, so read another.
	{
		myFile.ReadString (strLine);	
	}

	int loc1 = strLine.Find ('|',0);

	if (loc1==-1)  return;  // | not found in line after ----- TEST -----,
					        // must be another section, so return.

	//14 pipes.EV5 and 15 EV4 (pipes = fields-1)
	int nPipes = CountPipes(strLine);
	if (nVersion==EV5)
	{
		if (nPipes!=14)
		{
			char buf [10];
			itoa (nPipes,buf,10);
			CString strPipes = buf;
			CString strErr = "This EV5 file has "+strPipes +" | characters in the TEST section, should have 14.";
			MessageBox(NULL, strErr, "Error",MB_OK);
			return;
		}
	}
	else if(nVersion==EV4)
	{
		if (nPipes!=15)
		{
			char buf [10];
			itoa (nPipes,buf,10);
			CString strPipes = buf;
			CString strErr = "This EV4 file has "+strPipes +" | characters in the TEST section, should have 15.";
			MessageBox(NULL, strErr, "Error",MB_OK);
			return;
		}
	}	
		
	if (nVersion==EV4)  
	{
		//m_tstno = atoi(strLine.Mid(0, loc1 - 0)); // dont use tstno
		
		m_verno = GetTextBetweenPipes(strLine, 1,2);
		m_swgno= GetTextBetweenPipes(strLine, 2,3);
		m_title= GetTextBetweenPipes(strLine, 3,4);
		m_tstobj= GetTextBetweenPipes(strLine, 4,5);
		m_tstdat= GetTextBetweenPipes(strLine, 5,6);
		m_cerdat= GetTextBetweenPipes(strLine, 6,7);
		m_tstprf= GetTextBetweenPipes(strLine, 7,8);
		m_conno= GetTextBetweenPipes(strLine, 8,9);
		m_tstref= GetTextBetweenPipes(strLine, 9,10);
		m_tsttyp= GetTextBetweenPipes(strLine, 10,11);
		m_temp= GetTextBetweenPipes(strLine, 11,12);
		m_rectyp= GetTextBetweenPipes(strLine, 12,13);
		m_link= GetTextBetweenPipes(strLine, 13,14);
		m_totcrv= atoi(GetTextBetweenPipes(strLine, 14,15));
		m_tstcom = GetTextBetweenPipes(strLine, 15,16);
	}
	else //EV5
	{
		m_verno = GetTextBetweenPipes(strLine, 0,1);
		m_swgno= GetTextBetweenPipes(strLine, 1,2);
		m_title= GetTextBetweenPipes(strLine, 2,3);
		m_tstobj= GetTextBetweenPipes(strLine, 3,4);
		m_tstdat= GetTextBetweenPipes(strLine, 4,5);
		m_cerdat= GetTextBetweenPipes(strLine, 5,6);
		m_tstprf= GetTextBetweenPipes(strLine, 6,7);
		m_conno= GetTextBetweenPipes(strLine, 7,8);
		m_tstref= GetTextBetweenPipes(strLine, 8,9);
		m_tsttyp= GetTextBetweenPipes(strLine, 9,10);
		m_temp= GetTextBetweenPipes(strLine, 10,11);
		m_rectyp= GetTextBetweenPipes(strLine, 11,12);
		m_link= GetTextBetweenPipes(strLine, 12,13);
		m_totcrv= atoi(GetTextBetweenPipes(strLine, 13,14));
		m_tstcom = GetTextBetweenPipes(strLine, 14,15);
	}

	return;
}


// ------------------------------------
// BOOL ImportGR1(CString&)
// Description:  Opens GR1 file. Sets SWGData member vars with
//               Data found there, using the offsets defined in
//               SWGGR5.h
// ------------------------------------
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
BOOL CSWGData::ImportGR1(CString & strfile_in)
{
	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_in, CFile::modeRead | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_in, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return FALSE;
	}

	CString strLine;
	myFile.ReadString (strLine);

	if ((strLine.GetLength ()) <1) return FALSE;  // don't process empty string

	while (strLine[0]=='#')  //comment line, so read another.
	{
		myFile.ReadString (strLine);	
	}


	int nLen = strLine.GetLength ();
	if (nLen != m_GR1.m_totallen)
	{
		MessageBox(NULL,strfile_in+" is not in proper GR1 format.","ERROR", MB_OK);
		return FALSE;
	}
	// load member variables
	
	m_title = strLine.Mid(m_GR1.m_titleoff ,m_GR1.m_titlelen );
	m_tstobj = strLine.Mid(m_GR1.m_tstobjoff ,m_GR1.m_tstobjlen );
	m_tstdat = strLine.Mid(m_GR1.m_tstdatoff ,m_GR1.m_tstdatlen );
	m_tstprf = strLine.Mid(m_GR1.m_tstprfoff ,m_GR1.m_tstprflen );
	m_conno = strLine.Mid(m_GR1.m_connooff ,m_GR1.m_connolen );
	m_tstref = strLine.Mid(m_GR1.m_tstrefoff ,m_GR1.m_tstreflen );
	m_tsttyp = strLine.Mid(m_GR1.m_tsttypoff ,m_GR1.m_tsttyplen );
	m_temp = strLine.Mid(m_GR1.m_tempoff ,m_GR1.m_templen );
	m_rectyp = strLine.Mid(m_GR1.m_rectypoff ,m_GR1.m_rectyplen );
	m_link = strLine.Mid(m_GR1.m_linkoff ,m_GR1.m_linklen );
	//m_totcrv = atoi(strLine.Mid(m_GR1.m_totcrvoff ,m_GR1.m_totcrvlen ));  GR5 controlled.
	m_tstcom = strLine.Mid(m_GR1.m_tstcomoff ,m_GR1.m_tstcomlen );

	return TRUE;
}


// ------------------------------------
// BOOL ImportGR5(CString&)
// Description:  Opens GR5 file. Sets SWGData member vars with
//               Data found there, using the offsets defined in
//               SWGGR5.h
// ------------------------------------
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
BOOL CSWGData::ImportGR5(CString & strfile_in)
{
	CStdioFile myFile;
	CFileException fileException;
	
	myFile.Open( strfile_in, CFile::modeRead | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_in, fileException.m_cause );
		MessageBox(NULL,msg,"Error",MB_OK);
		return FALSE;
	}

	CString strLine;
	
	while(myFile.ReadString (strLine))
	{
		if ((strLine.GetLength ()) <1) return FALSE;  // don't process empty string

		while (strLine[0]=='#')  //comment line, so read another.
		{
			myFile.ReadString (strLine);	
		}

		int nLen = strLine.GetLength ();
		if (nLen != m_GR5.m_totallen)
		{
			MessageBox(NULL,strfile_in+" is not in proper GR5 format.","ERROR", MB_OK);
			return 0;
		}
		
		// load member variables  
		
		m_curno = atoi(strLine.Mid(m_GR5.m_curnooff ,m_GR5.m_curnolen ));
		m_sentyp.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_sentypoff ,m_GR5.m_sentyplen ));
		m_senloc.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_senlocoff ,m_GR5.m_senloclen ));
		m_senatt.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_senattoff ,m_GR5.m_senattlen ));
		m_axis.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_axisoff ,m_GR5.m_axislen ));
		m_xunits.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_unitsoff ,m_GR5.m_unitslen ));
		m_yunits.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_unitsoff ,m_GR5.m_unitslen ));
		m_prefil.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_prefiloff ,m_GR5.m_prefillen ) );
		m_insrat.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_insratoff ,m_GR5.m_insratlen ) );
		m_chlmax.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_chlmaxoff ,m_GR5.m_chlmaxlen ) );
		m_nfp.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_nfpoff ,m_GR5.m_nfplen ));
		m_nlp.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_nlpoff ,m_GR5.m_nlplen ));
		m_delt.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_deltoff ,m_GR5.m_deltlen ));
		m_dastat.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_dastatoff ,m_GR5.m_dastatlen ));
		m_chstat.SetAtGrow (m_curno, ""); //chstat isn't in GR5, so fill in data to avoid access violations
		m_inscom.SetAtGrow (m_curno, strLine.Mid(m_GR5.m_inscomoff ,m_GR5.m_inscomlen ));

		// These 2 don't exist in gr5.  Initialize them to avoid access violations.
		m_siglev.SetAtGrow (m_curno, 0); 
 		m_sigsrc.SetAtGrow (m_curno, "");
	}

	m_totcrv = m_curno;
	return m_curno;
}
