// -----------------------------------------
// Copyright 1998, Data Center, NRD of DOT
// File: SWGPropertySheet.cpp
//
// Author: Dan Robbins
//
// Date Created: October 1998
//
// Description:  CSWGPropertySheet is the container for all
//               the SWG...Pages.  The member functions here
//               process menu selections.
// -----------------------------------------

#include "stdafx.h"
#include "entreeV5.h"
#include "entreev5dlg.h"
#include "SWGPropertySheet.h"
#include "CodeValidation.h"

#include <winspool.h>


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif


/////////////////////////////////////////////////////////////////////////////
// CSWGPropertySheet

IMPLEMENT_DYNAMIC(CSWGPropertySheet, CPropertySheet)

/******************************************************************************
	Name:		
	Action:		
	Params:		
	Returns:	
	Notes:	
	Dates:
******************************************************************************/
CSWGPropertySheet::CSWGPropertySheet(UINT nIDCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(nIDCaption, pParentWnd, iSelectPage),
	_bClearAll( false )
{
	m_SWGTestPage.m_pSWGData	= &m_SWGData;   // the data is available inside Test info dlg
	m_SWGInstPage.m_pSWGData	= &m_SWGData;  // the data is available inside Inst info dlg
	m_HsvdPage.m_pSwgHsvdData	= &m_SWGData;
	m_HsvdPage.m_cVersion		= 'S';

	AddPage(&m_SWGTestPage);
	AddPage(&m_SWGInstPage);
	AddPage(&m_HsvdPage);

	m_pParent = (CChooseDB *) pParentWnd;
}

/******************************************************************************
	Name:		
	Action:		
	Params:		
	Returns:	
	Notes:	
	Dates:
******************************************************************************/
CSWGPropertySheet::CSWGPropertySheet(LPCTSTR pszCaption, CWnd* pParentWnd, UINT iSelectPage)
	:CPropertySheet(pszCaption, pParentWnd, iSelectPage),
	_bClearAll( false )
{
	
	m_SWGTestPage.m_pSWGData	= &m_SWGData;   // the data is available inside Test info dlg
	m_SWGInstPage.m_pSWGData	= &m_SWGData;  // the data is available inside Inst info dlg
	m_HsvdPage.m_pSwgHsvdData	= &m_SWGData;
	m_HsvdPage.m_cVersion		= 'S';

	AddPage(&m_SWGTestPage);
	AddPage(&m_SWGInstPage);
	AddPage(&m_HsvdPage);

	m_pParent = (CChooseDB *) pParentWnd;
}

/******************************************************************************
	Name:		
	Action:		
	Params:		
	Returns:	
	Notes:	
	Dates:
******************************************************************************/
CSWGPropertySheet::~CSWGPropertySheet()
{

}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
BEGIN_MESSAGE_MAP(CSWGPropertySheet, CPropertySheet)
	//{{AFX_MSG_MAP(CSWGPropertySheet)
	ON_COMMAND(ID_IMPORT_TEST, OnImportTest)
	ON_COMMAND(ID_EXPORT_TEST, OnExportTest)
	ON_COMMAND(ID_FILE_LOAD_HSVD, OnImportHsvdData)
	ON_COMMAND(ID_FILE_SAVE_HSVD, OnExportHsvdData)
	ON_COMMAND(ID_FILE_SAVE_HSVD_REPORT, OnExportHsvdReport)
	ON_COMMAND(ID_BIOMECHDB, OnBiomechdb)
	ON_COMMAND(ID_COMPONENTDB, OnComponentdb)
	ON_COMMAND(ID_VEHICLEDB, OnVehicledb)
	ON_COMMAND(ID_EXIT, OnExit)
	ON_COMMAND(ID_CLEARALL, OnClearall)
	ON_COMMAND(ID_FILE_PRINT, OnFilePrint)
	ON_COMMAND(ID_EXPORT_REPORT, OnExportReport)
	ON_WM_CLOSE()
	ON_COMMAND(ID_HELP_ABOUT, OnHelpAbout)
	ON_COMMAND(ID_HELP_INDEX, OnHelpIndex)
	ON_COMMAND(ID_HELP, OnHelpFinder)
	ON_WM_INITMENUPOPUP()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSWGPropertySheet message handlers

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
BOOL CSWGPropertySheet::OnInitDialog() 
{
	BOOL bResult = CPropertySheet::OnInitDialog();
	
	//Load Menu
	CMenu MyMenu;
	CMenu* pMenu=&MyMenu;
	pMenu->LoadMenu(IDR_PROPSHEET_MENU);
	// resize, buttons get cut off if you dont, because of menu.
    CRect rect;
	GetWindowRect(&rect);
    
	SetMenu(pMenu);

    MyMenu.CheckMenuItem (ID_SWGDB, MF_CHECKED);
	MyMenu.Detach ();  // MyMenu wont be deleted after this function.

	SetWindowPos(&wndTop, rect.left,rect.top, rect.Width() +15, rect.Height()+75, SWP_NOZORDER);

//	CRect helprect((rect.Width()/2)-30  , rect.bottom *4/5,(rect.Width()/2)+30, rect.bottom *17/20);
//	m_pHelpbutton->Create ("Help", WS_CHILD|WS_VISIBLE, helprect, this, ID_HELP);

	CenterWindow();
	
	HICON hICN = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
	SetIcon(hICN,FALSE);

	return bResult;
}

// Let the user choose a file to import, and then try to load it.
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnImportTest() 
{
	CFileDialog import(TRUE);
	import.m_ofn.lpstrTitle ="Open Test";
	import.m_ofn.lpstrFilter =
	 "EV5 Tests (*.ev5)\0*.ev5\0EV4 Tests (*.ev4)\0*.ev4\0EV3 Test Data (*.gr1)\0*.gr1\0EV3 Instrumentation Data (*.gr5)\0*.gr5\0";

	if (import.DoModal ()==IDOK)
	{		
		//import here
		CString strfile_in = import.GetPathName () ;
		CString strext = import.GetFileExt ();
		strext.MakeLower ();

		if (strext == "ev5") 
		{
			OnClearall();
			if( this->_bClearAll == false )
			{
				//	exit if user doesn't want to 
				//	replace current data with imported data.
				return;
			}

			BOOL success = m_SWGData.ImportEV5(strfile_in);
			if (success) 
			{
				m_SWGTestPage.OnSetActive ();
				m_SWGInstPage.m_icurno = m_SWGData.m_totcrv;  //goto last curve.
				if (m_SWGInstPage.m_hWnd)
				{
					m_SWGInstPage.OnSetActive();
				}
			}

			// import High Speed Video data
			strfile_in.TrimRight();
			CString HsvdFile = strfile_in.Left(strfile_in.GetLength()-4) + ".hs5";
			ImportHsvdData(HsvdFile, false);
		}
		else if (strext=="ev4")
		{
			OnClearall();
			if( this->_bClearAll == false )
			{
				//	exit if user doesn't want to 
				//	replace current data with imported data.
				return;
			}

			BOOL success = m_SWGData.ImportEV4(strfile_in);
			if (success) 
			{
				m_SWGTestPage.OnSetActive ();
				m_SWGInstPage.m_icurno = m_SWGData.m_totcrv;  //goto last curve.
				if (m_SWGInstPage.m_hWnd)
				{
					m_SWGInstPage.OnSetActive();
				}
			}
			
		}
		else if (strext=="gr1")
		{
			BOOL success= m_SWGData.ImportGR1(strfile_in);
			if (success) 
			{
				m_SWGTestPage.OnSetActive ();
				if (m_SWGInstPage.m_hWnd) m_SWGInstPage.OnSetActive();
			}
			
		}
		else if (strext=="gr5")
		{
			BOOL success= m_SWGData.ImportGR5(strfile_in);
			if (success) 
			{
				m_SWGTestPage.OnSetActive ();
				m_SWGInstPage.m_icurno = m_SWGData.m_totcrv;  //goto last curve.
				if (m_SWGInstPage.m_hWnd) m_SWGInstPage.OnSetActive();
			}
			
		}
		
	}


}

// Load data from all pages into SWGData.  If success,
// let the user export an EV5 file containing this data.
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnExportTest() 
{

	// Get latest data from pages - if already loaded, no big deal.
	if (!m_SWGTestPage.LoadSWGTestData ()) return;
	if (!m_SWGInstPage.LoadSWGInstData ()) return;
	
	// File export dialog common control
	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Export File";
	export.m_ofn.lpstrFilter = "EV5 File (*.ev5)\0*.ev5\0";

	if (export.DoModal()==IDOK)
	{
		//export here
		CString strfile_out = export.GetPathName ();
		if (export.GetFileExt ()!="ev5")
		{
			strfile_out +=".ev5";
		}
		m_SWGData.ExportEV5 (strfile_out);	
		
		// export high-speed video data
		if( m_SWGData.m_camno.GetSize()<2 ) { return; }

		if ( !m_HsvdPage.ValidateThisPage() ) 
		{ 
			AfxMessageBox("Illegal data found. No file output.");
			return; 
		}

		strfile_out.TrimRight();
		CString HsvdFile = strfile_out.Left(strfile_out.GetLength()-4) + ".hs5";
		m_SWGData.ExportHsvd( HsvdFile );
	}
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnBiomechdb() 
{
	if (MessageBox("Exit SWG Data Screens?",NULL,MB_YESNO)==IDYES)
	{
		CPropertySheet::OnClose();
		m_pParent->OnBiomechButton ();	
	}
	
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnComponentdb() 
{
	if (MessageBox("Exit SWG Data Screens?",NULL,MB_YESNO)==IDYES)
	{
		CPropertySheet::OnClose();
		m_pParent->OnComponentButton ();	
	}
	
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnVehicledb() 
{
	if (MessageBox("Exit SWG Data Screens?",NULL,MB_YESNO)==IDYES)
	{
		CPropertySheet::OnClose();
		m_pParent->OnVehicleButton ();	
	}
	
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnExit() 
{
	OnClose();
}

/******************************************************************************

	Name:		OnClearall

	Action:		This function is long.  Clear all edit boxes.  Clear all data
				from all arrays in m_SWGData.  Then, reinitialize both with
				defaults.

	Params:		void

	Returns:	BOOL

	Notes:	

	Dates:		Modify -- Al Wilhelm -- 03/09/2000

******************************************************************************/
void CSWGPropertySheet::OnClearall( void ) 
{
	if( AfxMessageBox("Really clear all current entries?", MB_YESNO ) == IDNO )
	{
		this->_bClearAll = false;
		return;	// was returning FALSE;
	}

	// Clear all SWGData
	m_SWGData.m_swgno	= _T("");
	m_SWGData.m_title	= _T("");
	m_SWGData.m_tstobj	= _T("");
	m_SWGData.m_tstdat	= _T("");
	m_SWGData.m_cerdat	= _T("");
	m_SWGData.m_tstprf	= _T("");
	m_SWGData.m_conno	= _T("");
	m_SWGData.m_tstref	= _T("");
	m_SWGData.m_tsttyp	= _T("");
	m_SWGData.m_temp	= _T("");
	m_SWGData.m_rectyp	= _T("");
	m_SWGData.m_link	= _T("");
	m_SWGData.m_totcrv	= 0;
	m_SWGData.m_tstcom	= _T("");
	m_SWGData.m_curno	= 0;
	m_SWGData.m_sigsrc.RemoveAll ();
	m_SWGData.m_siglev.RemoveAll ();
	m_SWGData.m_sentyp.RemoveAll ();
	m_SWGData.m_senloc.RemoveAll ();
	m_SWGData.m_senatt.RemoveAll ();
	m_SWGData.m_axis.RemoveAll ();
	m_SWGData.m_xunits.RemoveAll ();
	m_SWGData.m_yunits.RemoveAll ();
	m_SWGData.m_prefil.RemoveAll ();
	m_SWGData.m_insrat.RemoveAll ();
	m_SWGData.m_chlmax.RemoveAll ();
	m_SWGData.m_nfp.RemoveAll ();
	m_SWGData.m_nlp.RemoveAll ();
	m_SWGData.m_delt.RemoveAll ();
	m_SWGData.m_dastat.RemoveAll ();
	m_SWGData.m_chstat.RemoveAll ();
	m_SWGData.m_inscom.RemoveAll ();
	m_SWGData.m_axis.SetAtGrow(0,""); m_SWGData.m_axis.SetAtGrow (1, "");
    m_SWGData.m_chlmax.SetAtGrow (0,""); m_SWGData.m_chlmax.SetAtGrow(1,"" );
	m_SWGData.m_chstat.SetAtGrow(0,""); m_SWGData.m_chstat.SetAtGrow (1, "");
	m_SWGData.m_dastat.SetAtGrow(0,""); m_SWGData.m_dastat.SetAtGrow (1, "");
	m_SWGData.m_delt.SetAtGrow(0,0); m_SWGData.m_delt.SetAtGrow (1, "" );
	m_SWGData.m_inscom.SetAtGrow(0,""); m_SWGData.m_inscom.SetAtGrow (1, "");
	m_SWGData.m_insrat.SetAtGrow(0,""); m_SWGData.m_insrat.SetAtGrow (1, "" );
	m_SWGData.m_nfp.SetAtGrow(0,""); m_SWGData.m_nfp.SetAtGrow (1, "" );
	m_SWGData.m_nlp.SetAtGrow(0,""); m_SWGData.m_nlp.SetAtGrow (1, "" );
	m_SWGData.m_prefil.SetAtGrow(0,""); m_SWGData.m_prefil.SetAtGrow (1, "" );
	m_SWGData.m_senatt.SetAtGrow(0,""); m_SWGData.m_senatt.SetAtGrow (1, "");
    m_SWGData.m_senloc.SetAtGrow(0,""); m_SWGData.m_senloc.SetAtGrow (1, "");
	m_SWGData.m_sentyp.SetAtGrow(0,""); m_SWGData.m_sentyp.SetAtGrow (1, "");
	m_SWGData.m_siglev.SetAtGrow(0,"5"); m_SWGData.m_siglev.SetAtGrow (1, "5");
	m_SWGData.m_sigsrc.SetAtGrow(0,""); m_SWGData.m_sigsrc.SetAtGrow (1, "");
	m_SWGData.m_xunits.SetAtGrow(0,"SEC"); m_SWGData.m_xunits.SetAtGrow (1, "SEC");
	m_SWGData.m_yunits.SetAtGrow(0,""); m_SWGData.m_yunits.SetAtGrow (1, "");
	
	// CSWGTestPage -- BEGIN
	m_SWGTestPage.m_link	= _T("");
	m_SWGTestPage.m_rectyp	= _T("");
	m_SWGTestPage.m_tstprf	= _T("");
	m_SWGTestPage.m_tsttyp	= _T("");
	m_SWGTestPage.m_conno	= _T("");
	m_SWGTestPage.m_swgno	= _T("");
	m_SWGTestPage.m_temp	= _T("");
	m_SWGTestPage.m_title	= _T("");
	m_SWGTestPage.m_totcrv	= _T("0");
	m_SWGTestPage.m_tstcom	= _T("");
	m_SWGTestPage.m_tstobj	= _T("");
	m_SWGTestPage.m_tstref	= _T("");
	m_SWGTestPage.m_verno	= _T("S5");
	// CSWGTestPage -- END

	// CSWGInstPage -- BEGIN
	m_SWGInstPage.m_axis		= _T("");
	m_SWGInstPage.m_chlmax		= _T("");
	m_SWGInstPage.m_chstat		= _T("");
	m_SWGInstPage.m_dastat		= _T("");
	m_SWGInstPage.m_delt		= _T("");
	m_SWGInstPage.m_inscom		= _T("");
	m_SWGInstPage.m_insrat		= _T("");
	m_SWGInstPage.m_nfp			= _T("");
	m_SWGInstPage.m_nlp			= _T("");
	m_SWGInstPage.m_prefil		= _T("");
	m_SWGInstPage.m_senatt		= _T("");
	m_SWGInstPage.m_senloc		= _T("");
	m_SWGInstPage.m_sentyp		= _T("");
	m_SWGInstPage.m_siglev		= _T("5");
	m_SWGInstPage.m_sigsrc		= _T("");
	m_SWGInstPage.m_xunits		= _T("SEC");
	m_SWGInstPage.m_yunits		= _T("");
	m_SWGInstPage.m_retaindata	= FALSE;
	m_SWGInstPage.m_icurno		= 0;	// Default to first curve.
	m_SWGInstPage.m_totalcurves	= 0;	// Initialize total curves.
	// CSWGInstPage -- END


	if (m_SWGTestPage.m_hWnd!=NULL)
	{
		m_SWGTestPage.UpdateData(FALSE);
	}

	if (m_SWGInstPage.m_hWnd!=NULL)
	{
		m_SWGInstPage.m_curvelist.ResetContent();
		m_SWGInstPage.UpdateData(FALSE);
	}
	
	m_SWGData.ClearHsvddata();
	if (m_HsvdPage.m_hWnd!=NULL) { m_HsvdPage.ClearAll(); }	// for high speed video

	this->_bClearAll = true;
	return;	// was returning TRUE;
}

/******************************************************************************

	Name:		OnFilePrint

	Action:		

	Params:		void

	Returns:	void

	Notes:		Ask user which file to print.  Then ask which printer to print
				with.  Then do an annoying line by line print loop.  There must
				be a better way to do this.  See ch15 from Programming
				Windows 95 by Petzold.

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnFilePrint( void ) 
{

	CString strfile_out= GetPrintFileName();
	if (strfile_out=="") return;  // no file chosen, cancel.

	CString device = GetPrinterDeviceName();
	if (device == "") return; // no printer chosen, cancel.

	CStdioFile myFile;
	CFileException fileException;

	myFile.Open( strfile_out, CFile::shareDenyNone | CFile::modeRead | CFile::typeText,
		&fileException );
	if (!myFile.m_pStream)  // not opened, will be NULL.
	{
		CString msg;
		msg.Format ("Can't open file %s, error = %u\n", strfile_out, fileException.m_cause );
		MessageBox(msg);
		return ;
	}
	
	static DOCINFO di={sizeof(DOCINFO), strfile_out,NULL};

	HDC hdcPrn = CreateDC("WINSPOOL", device, NULL, NULL);

	// size of page and chars and lines per page.
	TEXTMETRIC tm;
	GetTextMetrics(hdcPrn, &tm);
	int yChar, nline = 0;
	yChar = tm.tmHeight +tm.tmExternalLeading;
	
	int iCharsPerLine = GetDeviceCaps(hdcPrn, HORZRES) /tm.tmAveCharWidth ;
	int iLinesPerPage = GetDeviceCaps(hdcPrn, VERTRES) / yChar;

	

	StartDoc (hdcPrn, &di);
	StartPage (hdcPrn);
	
	CString strbuf;
	char* pBuf = new char[iCharsPerLine + 1];
	// readstrings from file.  
	while (myFile.ReadString(pBuf, iCharsPerLine)) //reads max of iCharsPerLine chars.
	{
		if (nline == iLinesPerPage)  //new page
		{
			nline = 0;
			EndPage(hdcPrn);
			StartPage(hdcPrn);
		}
		// WARNING! TextOut doesn't handle Tabs well, so there are no tabs in .ev5 or .evr.
		strbuf = pBuf;
		TextOut(hdcPrn,0,yChar*nline, strbuf, strbuf.GetLength ());
		nline++;
		
	}

	EndPage(hdcPrn);
	EndDoc(hdcPrn);
	DeleteDC(hdcPrn);
	delete [] pBuf;
	myFile.Close ();
	return;

}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
CString CSWGPropertySheet::GetPrintFileName()
{
	// Get Print File Name  **********
	CFileDialog printfile(TRUE);
	CString strfile_out;
	printfile.m_ofn.lpstrTitle ="Choose File To Print";
	printfile.m_ofn.lpstrFilter = "EV5 File (*.ev5)\0*.ev5\0EV5 Report File (*.evr)\0*.evr\0";

	if (printfile.DoModal()==IDOK)
	{
		strfile_out = printfile.GetPathName ();
	}
	else
	{
		strfile_out = _T("");
	}
	return strfile_out;

}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
CString CSWGPropertySheet::GetPrinterDeviceName()
{
	CString device;
	// Choose Printer to use ************
	CPrintDialog printmachine(FALSE);
	
	if (printmachine.DoModal ()==IDOK)
	{
		device = printmachine.GetDeviceName();
		GlobalFree(printmachine.m_pd.hDevMode );
		GlobalFree(printmachine.m_pd.hDevNames );
	}
	else
	{
		GlobalFree(printmachine.m_pd.hDevMode );
		GlobalFree(printmachine.m_pd.hDevNames );
		device = _T("");
	}
	return device;

}

// Try to load all data into m_SWGData.  If success,
// let the user export this data into a report (EVR) file.
/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnExportReport() 
{
	// Get latest data from pages - if already loaded, no big deal.
	if (!m_SWGTestPage.LoadSWGTestData ()) return;
	if (!m_SWGInstPage.LoadSWGInstData ()) return;

	// File export dialog common control
	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Export Report";
	export.m_ofn.lpstrFilter = "EV5 Report (*.evr)\0*.evr\0";

	if (export.DoModal()==IDOK)
	{
		//export here
//		CString strfile_out = export.GetPathName () + ".evr";
//		m_SWGData.ExportEVR (strfile_out);
		CString strfile_out = export.GetPathName ();
		if (export.GetFileExt ()!="evr")
		{
			strfile_out +=".evr";
		}
		m_SWGData.ExportEVR (strfile_out);

		// Export high speed video report
		if( m_SWGData.m_camno.GetSize()<2 ) { return; }

		if ( !m_HsvdPage.ValidateThisPage() ) 
		{ 
			AfxMessageBox("Illegal data found. No file output.");
			return; 
		}

		strfile_out.TrimRight();
		CString HsvdFile = strfile_out.Left(strfile_out.GetLength()-4) + ".hsr";
		m_SWGData.ExportHsvdReport( HsvdFile );
	}
	
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnClose() 
{
	if (MessageBox("Really exit Entree?", "Warning", MB_YESNO)==IDYES)
	{
		m_pParent->DoneChoose();	
		
	}
}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnHelpAbout() 
{
	CAboutDlg about;
	about.DoModal ();

}

/******************************************************************************

	Name:		

	Action:		

	Params:		

	Returns:	

	Notes:	

	Dates:

******************************************************************************/
void CSWGPropertySheet::OnHelpIndex() 
{
	OnHelpFinder();	
	
}

void CSWGPropertySheet::OnInitMenuPopup(CMenu* pPopupMenu, UINT nIndex, BOOL bSysMenu) 
{
	CPropertySheet::OnInitMenuPopup(pPopupMenu, nIndex, bSysMenu);

	if(		( m_SWGTestPage.ValidatePage() == true ) 
		&&	( m_SWGInstPage.ValidatePage() == true ) )
	{
		pPopupMenu->EnableMenuItem( ID_EXPORT_TEST, MF_ENABLED );		
	}
	else
	{
		pPopupMenu->EnableMenuItem( ID_EXPORT_TEST, MF_GRAYED );
	}

	// for intrusion point
	pPopupMenu->EnableMenuItem( ID_FILE_LOAD_INTRUSION, MF_GRAYED );
	pPopupMenu->EnableMenuItem( ID_FILE_SAVE_INTRUSION, MF_GRAYED );
	pPopupMenu->EnableMenuItem( ID_FILE_SAVE_INTRUSION_REPORT, MF_GRAYED );
}

////////////// for high-speed video files only
void CSWGPropertySheet::OnImportHsvdData()
{
	CFileDialog import(TRUE);
	import.m_ofn.lpstrTitle ="Open High-Speed Video File";
	import.m_ofn.lpstrFilter = "EV5 HSVD (*.hs5)\0*.hs5\0";
//	 "EV5 Tests (*.ev5)\0*.ev5\0EV4 Tests (*.ev4)\0*.ev4\0EV3 Test Data (*.gr1)\0*.gr1\0EV3 Vehicle Data (*.gr2)\0*.gr2\0EV3 Barrier Data (*.gr3)\0*.gr3\0EV3 Occupant Data (*.gr4)\0*.gr4\0EV3 Instrumentation Data (*.gr5)\0*.gr5\0";
	 
	if (import.DoModal ()==IDCANCEL) { return; }
	CString strfile_in = import.GetPathName () ;
	ImportHsvdData(strfile_in);
}	// OnImportHsvdData

void CSWGPropertySheet::OnExportHsvdData()
{
	ExportHsvdData();
}	// OnExportHsvdData

void CSWGPropertySheet::ImportHsvdData(CString& strfile_in, bool bErrMsgResponse) // = true
{
	if( !m_SWGData.ImportHsvd(strfile_in, bErrMsgResponse) ) { return; }
	m_HsvdPage.m_nCurCamNo = m_HsvdPage.m_nTotalCamNo = m_SWGData.m_camno.GetSize() - 1;	// the 0th item is empty.
	m_SWGTestPage.OnSetActive ();  //m_hWnd always exists
	if (m_HsvdPage.m_hWnd) m_HsvdPage.OnSetActive();

}	// ImportHsvdData

void CSWGPropertySheet::ExportHsvdData()
{
	if( m_SWGData.m_camno.GetSize()<2 ) { return; }
//	m_HsvdPage.LoadHsvdData();
	
	if ( !m_HsvdPage.ValidateThisPage() ) 
	{ 
		AfxMessageBox("Illegal data found. No file output.");
		return; 
	}

	//File Export Dialog Common Control
	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Export File";
	export.m_ofn.lpstrFilter = "EV5 HSVD (*.hs5)\0*.hs5\0";

	if( export.DoModal() == IDCANCEL ) { return; }
	
	//export here
	CString strfile_out = export.GetPathName();
	if( export.GetFileExt() != "hs5" )
	{
		strfile_out += ".hs5";
	}

	m_SWGData.ExportHsvd( strfile_out );

}	// ExportHsvdData

void CSWGPropertySheet::OnExportHsvdReport()
{
	ExportHsvdReport();
}	// OnExportHsvdReport


void CSWGPropertySheet::ExportHsvdReport()
{
	if( m_SWGData.m_camno.GetSize()==0 ) { return; }
		
	if ( !m_HsvdPage.ValidateThisPage() ) 
	{ 
		AfxMessageBox("Illegal data found. No file output.");
		return; 
	}

	//File Export Dialog Common Control
	CFileDialog export(FALSE);
	export.m_ofn.lpstrTitle ="Report File";
	export.m_ofn.lpstrFilter = "EV5 HSVD (*.hsr)\0*.hsr\0";

	if( export.DoModal() == IDCANCEL ) { return; }
	
	//export here
	CString strfile_out = export.GetPathName();
	if( export.GetFileExt() != "hsr" )
	{
		strfile_out += ".hsr";
	}

	m_SWGData.ExportHsvdReport( strfile_out );

}	// ExportHsvdReport